@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2007 Joe Wreschnig, Michael Urman, Iñigo Serna
 #           2009-2010 Steven Robertson
-#           2012-2013 Nick Boultbee
+#      2012,2013,2016 Nick Boultbee
 #           2009-2014 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -14,17 +14,17 @@ import os
 
 from gi.repository import Gtk, Pango, Gdk, GLib, Gio
 
-from .prefs import Preferences, PATTERN
+from .prefs import Preferences, DEFAULT_PATTERN_TEXT
 from .models import AlbumModel, AlbumFilterModel, AlbumSortModel
 
+import quodlibet
 from quodlibet import config
-from quodlibet import const
 from quodlibet import qltk
 from quodlibet import util
 
-from quodlibet.browsers._base import Browser
+from quodlibet.browsers import Browser
 from quodlibet.query import Query
-from quodlibet.pattern import XMLFromMarkupPattern
+from quodlibet.browsers._base import DisplayPatternMixin
 from quodlibet.qltk.completion import EntryWordCompletion
 from quodlibet.qltk.information import Information
 from quodlibet.qltk.properties import SongProperties
@@ -34,16 +34,13 @@ from quodlibet.qltk.x import MenuItem, Align, ScrolledWindow, RadioMenuItem
 from quodlibet.qltk.x import SymbolicIconImage
 from quodlibet.qltk.searchbar import SearchBarBox
 from quodlibet.qltk.menubutton import MenuButton
+from quodlibet.qltk import Icons
 from quodlibet.util import copool, connect_destroy
 from quodlibet.util.library import background_filter
 from quodlibet.util import connect_obj, DeferredSignal
 from quodlibet.util.collection import Album
 from quodlibet.qltk.cover import get_no_cover_pixbuf
-from quodlibet.qltk.image import (get_pbosf_for_pixbuf, get_scale_factor,
-    set_renderer_from_pbosf, add_border_widget)
-
-
-PATTERN_FN = os.path.join(const.USERDIR, "album_pattern")
+from quodlibet.qltk.image import add_border_widget, get_surface_for_pixbuf
 
 
 class AlbumTagCompletion(EntryWordCompletion):
@@ -77,10 +74,10 @@ def cmpa(a, b):
 
 
 def compare_title(a1, a2):
-    # all albums has to stay at the top
+    # All albums should stay at the top
     if (a1 and a2) is None:
         return cmp(a1, a2)
-    # move album without a title to the bottom
+    # Move albums without a title to the bottom
     if not a1.title:
         return 1
     if not a2.title:
@@ -177,14 +174,14 @@ class PreferencesButton(Gtk.HBox):
         sort_item.set_submenu(sort_menu)
         menu.append(sort_item)
 
-        pref_item = MenuItem(_("_Preferences"), Gtk.STOCK_PREFERENCES)
+        pref_item = MenuItem(_("_Preferences"), Icons.PREFERENCES_SYSTEM)
         menu.append(pref_item)
         connect_obj(pref_item, "activate", Preferences, browser)
 
         menu.show_all()
 
         button = MenuButton(
-                SymbolicIconImage("emblem-system", Gtk.IconSize.MENU),
+                SymbolicIconImage(Icons.EMBLEM_SYSTEM, Gtk.IconSize.MENU),
                 arrow=True)
         button.set_menu(menu)
         self.pack_start(button, True, True, 0)
@@ -290,8 +287,8 @@ class VisibleUpdate(object):
 
         model = view.get_model()
 
-        #generate a path list so that cover scanning starts in the middle
-        #of the visible area and alternately moves up and down
+        # Generate a path list so that cover scanning starts in the middle
+        # of the visible area and alternately moves up and down.
         start, end = vrange
 
         # pygtk2.12 sometimes returns empty tuples
@@ -330,14 +327,18 @@ class VisibleUpdate(object):
         self.__pending_paths = visible_paths
 
 
-class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
-    __gsignals__ = Browser.__gsignals__
+class AlbumList(Browser, util.InstanceTracker, VisibleUpdate,
+                DisplayPatternMixin):
     __model = None
     __last_render = None
-    __last_render_pb = None
+    __last_render_surface = None
+
+    _PATTERN_FN = os.path.join(quodlibet.get_user_dir(), "album_pattern")
+    _DEFAULT_PATTERN_TEXT = DEFAULT_PATTERN_TEXT
 
     name = _("Album List")
     accelerated_name = _("_Album List")
+    keys = ["AlbumList"]
     priority = 4
 
     def pack(self, songpane):
@@ -352,12 +353,7 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
 
     @classmethod
     def init(klass, library):
-        try:
-            klass._pattern_text = file(PATTERN_FN).read().rstrip()
-        except EnvironmentError:
-            klass._pattern_text = PATTERN
-
-        klass._pattern = XMLFromMarkupPattern(klass._pattern_text)
+        super(AlbumList, klass).load_pattern()
 
     @classmethod
     def _destroy_model(klass):
@@ -373,16 +369,8 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
                 column.queue_resize()
 
     @classmethod
-    def refresh_pattern(klass, pattern_text):
-        if pattern_text == klass._pattern_text:
-            return
-        klass._pattern_text = pattern_text
-        klass._pattern = XMLFromMarkupPattern(pattern_text)
-        klass.__model.refresh_all()
-        pattern_fn = PATTERN_FN
-        f = file(pattern_fn, "w")
-        f.write(pattern_text + "\n")
-        f.close()
+    def refresh_all(cls):
+        cls.__model.refresh_all()
 
     @classmethod
     def _init_model(klass, library):
@@ -398,15 +386,17 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
 
     @util.cached_property
     def _no_cover(self):
-        """Returns a cairo surface of pixbuf representing a missing cover"""
+        """Returns a cairo surface representing a missing cover"""
 
         cover_size = Album.COVER_SIZE
-        scale_factor = get_scale_factor(self)
+        scale_factor = self.get_scale_factor()
         pb = get_no_cover_pixbuf(cover_size, cover_size, scale_factor)
-        return get_pbosf_for_pixbuf(self, pb)
+        return get_surface_for_pixbuf(self, pb)
 
     def __init__(self, library):
         super(AlbumList, self).__init__(spacing=6)
+        self.set_orientation(Gtk.Orientation.VERTICAL)
+
         self._register_instance()
         if self.__model is None:
             self._init_model(library)
@@ -436,22 +426,20 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
             album = model.get_album(iter_)
 
             if album is None:
-                pixbuf = None
+                surface = None
             elif album.cover:
                 pixbuf = album.cover
-                round_ = config.getboolean("albumart", "round")
-                pixbuf = add_border_widget(
-                    pixbuf, self.view, cell, round_)
-                pixbuf = get_pbosf_for_pixbuf(self, pixbuf)
+                pixbuf = add_border_widget(pixbuf, self.view)
+                surface = get_surface_for_pixbuf(self, pixbuf)
                 # don't cache, too much state has an effect on the result
-                self.__last_render_pb = None
+                self.__last_render_surface = None
             else:
-                pixbuf = no_cover
+                surface = no_cover
 
-            if self.__last_render_pb == pixbuf:
+            if self.__last_render_surface == surface:
                 return
-            self.__last_render_pb = pixbuf
-            set_renderer_from_pbosf(cell, pixbuf)
+            self.__last_render_surface = surface
+            cell.set_property("surface", surface)
 
         column.set_cell_data_func(render, cell_data_pb, self._no_cover)
         view.append_column(column)
@@ -471,7 +459,7 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
                         len(model) - 1) % (len(model) - 1)
                 markup = text
             else:
-                markup = AlbumList._pattern % album
+                markup = self.display_pattern % album
 
             if self.__last_render == markup:
                 return
@@ -491,10 +479,8 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
         sw.add(view)
 
         view.connect('row-activated', self.__play_selection)
-
-        self.__sig = connect_destroy(
-            view.get_selection(), 'changed',
-            util.DeferredSignal(self.__update_songs, owner=self))
+        self.__sig = view.connect('selection-changed',
+            util.DeferredSignal(self.__update_songs, owner=view))
 
         targets = [("text/x-quodlibet-songs", Gtk.TargetFlags.SAME_APP, 1),
                    ("text/uri-list", 0, 2)]
@@ -526,7 +512,7 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
         self.show_all()
 
     def __key_pressed(self, widget, event, librarian):
-        if qltk.is_accel(event, "<ctrl>I"):
+        if qltk.is_accel(event, "<Primary>I"):
             songs = self.__get_selected_songs()
             if songs:
                 window = Information(librarian, songs, self)
@@ -557,7 +543,7 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
                 model.row_changed(path, model.get_iter(path))
 
         album = model.get_album(iter_)
-        scale_factor = get_scale_factor(self)
+        scale_factor = self.get_scale_factor()
         album.scan_cover(scale_factor=scale_factor,
                          callback=callback,
                          cancel=self._cover_cancel)
@@ -584,12 +570,12 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
 
         # We could be smart and try to scroll to a selected album
         # but that introduces lots of wild scrolling. Feel free to change it.
-        # Without scrolling the TV trys to stay at the same position (40% down)
-        # which makes no sence so always go to the top.
+        # Without scrolling the TV tries to stay at the same position
+        # (40% down) which makes no sense, so always go to the top.
         if scroll_up:
             self.view.scroll_to_point(0, 0)
 
-        # don't filter on restore if there is nothing to filter
+        # Don't filter on restore if there is nothing to filter
         if not restore or self.__filter or self.__bg_filter:
             model.refilter()
 
@@ -635,7 +621,7 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
             num = len(albums)
             button = MenuItem(
                 ngettext("Reload album _cover", "Reload album _covers", num),
-                Gtk.STOCK_REFRESH)
+                Icons.VIEW_REFRESH)
             button.connect('activate', self.__refresh_album, view)
             items.append(button)
 
@@ -698,9 +684,12 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
             self.__uninhibit()
             self.activate()
 
+    def get_filter_text(self):
+        return self.__search.get_text()
+
     def can_filter(self, key):
-        # numerics are different for collections, and title
-        # works, but not of much use here
+        # Numerics are different for collections, and although title works,
+        # it's not of much use here.
         if key is not None and (key.startswith("~#") or key == "title"):
             return False
         return super(AlbumList, self).can_filter(key)
@@ -728,10 +717,10 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
         self.view.get_selection().emit('changed')
 
     def __inhibit(self):
-        self.view.get_selection().handler_block(self.__sig)
+        self.view.handler_block(self.__sig)
 
     def __uninhibit(self):
-        self.view.get_selection().handler_unblock(self.__sig)
+        self.view.handler_unblock(self.__sig)
 
     def restore(self):
         text = config.get("browsers", "query_text").decode("utf-8")
@@ -788,6 +777,6 @@ class AlbumList(Browser, Gtk.VBox, util.InstanceTracker, VisibleUpdate):
         text = self.__search.get_text().encode("utf-8")
         config.set("browsers", "query_text", text)
 
-    def __update_songs(self, selection):
+    def __update_songs(self, view, selection):
         songs = self.__get_selected_songs(sort=False)
         self.songs_selected(songs)
