@@ -20,8 +20,8 @@ from quodlibet.qltk.searchbar import SearchBarBox
 from quodlibet.qltk.songsmenu import SongsMenu
 from quodlibet.qltk.views import AllTreeView
 from quodlibet.qltk import Icons
-from quodlibet.qltk.image import (get_scale_factor, get_pbosf_for_pixbuf,
-    set_renderer_from_pbosf, scale, add_border_widget)
+from quodlibet.qltk.image import scale, add_border_widget, \
+    get_surface_for_pixbuf
 from quodlibet.qltk.x import ScrolledWindow, Align, SymbolicIconImage
 from quodlibet.util.collection import Album
 from quodlibet.util import connect_obj
@@ -189,7 +189,7 @@ class CollectionBrowser(Browser, util.InstanceTracker):
             # XXX: Cache this somewhere else
             cover = None
             if not hasattr(album, "_scaled_cover"):
-                scale_factor = get_scale_factor(self)
+                scale_factor = self.get_scale_factor()
                 album.scan_cover(scale_factor=scale_factor)
                 if album.cover:
                     s = 25 * scale_factor
@@ -206,11 +206,9 @@ class CollectionBrowser(Browser, util.InstanceTracker):
             else:
                 cover = get_scaled_cover(album)
                 if cover:
-                    round_ = config.getboolean("albumart", "round")
-                    cover = add_border_widget(
-                        cover, view, cell, round=round_)
-                    pbosf = get_pbosf_for_pixbuf(self, cover)
-                    set_renderer_from_pbosf(cell, pbosf)
+                    cover = add_border_widget(cover, view)
+                    surface = get_surface_for_pixbuf(self, cover)
+                    cell.set_property("surface", surface)
                 else:
                     cell.set_property('icon-name', Icons.MEDIA_OPTICAL)
 
