@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
-#                2012 Nick Boultbee
+#           2012,2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -27,8 +27,7 @@ from quodlibet.qltk import Icons
 from quodlibet.util import copool
 from quodlibet.util.library import get_scan_dirs
 from quodlibet.util.dprint import print_d
-from quodlibet.util.uri import URI
-from quodlibet.util.path import normalize_path
+from quodlibet.util.path import normalize_path, uri_from_path
 from quodlibet.util import connect_obj
 
 
@@ -120,8 +119,8 @@ class FileSystem(Browser, Gtk.HBox):
             qltk.selection_set_songs(sel, songs)
         else:
             # External target (app) is delivered a list of URIS of songs
-            uris = list({URI.frompath(dir) for dir in dirs})
-            print_d("Directories to drop: %s" % [u.filename for u in uris])
+            uris = list({uri_from_path(dir) for dir in dirs})
+            print_d("Directories to drop: %s" % dirs)
             sel.set_uris(uris)
 
     def can_filter_tag(self, key):
@@ -148,7 +147,8 @@ class FileSystem(Browser, Gtk.HBox):
 
         paths = map(normalize_path, paths)
 
-        def select(model, path, iter_, (paths, first)):
+        def select(model, path, iter_, paths_):
+            (paths, first) = paths_
             value = model.get_value(iter_)
             if value is None:
                 return not bool(paths)
@@ -194,7 +194,7 @@ class FileSystem(Browser, Gtk.HBox):
 
         items.append([i])
         menu = SongsMenu(library, songs, remove=self.__remove_songs,
-                         delete=True, items=items)
+                         delete=True, queue=True, items=items)
         return menu
 
     def __add_songs(self, item, songs):
