@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2011 Joe Wreschnig, Christoph Reiter
+#           2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -8,39 +9,43 @@
 import os
 import sys
 import bz2
-import urllib2
-import urllib
 import itertools
 
 from gi.repository import Gtk, GLib, Pango
 
-from quodlibet import const
+from quodlibet.util.dprint import print_d
+
+import quodlibet
 from quodlibet import qltk
 from quodlibet import util
 from quodlibet import config
 
-from quodlibet.browsers._base import Browser
+from quodlibet.browsers import Browser
 from quodlibet.formats.remote import RemoteFile
 from quodlibet.formats._audio import TAG_TO_SORT, MIGRATE, AudioFile
 from quodlibet.library import SongLibrary
-from quodlibet.parse import Query
+from quodlibet.query import Query
+from quodlibet.compat import reduce, urlopen
 from quodlibet.qltk.getstring import GetStringDialog
 from quodlibet.qltk.songsmenu import SongsMenu
 from quodlibet.qltk.notif import Task
-from quodlibet.util import copool, gobject_weak, sanitize_tags
+from quodlibet.qltk import Icons, ErrorMessage, WarningMessage
+from quodlibet.util import copool, connect_destroy, sanitize_tags, \
+    connect_obj, escape
+from quodlibet.util.path import uri_is_valid
 from quodlibet.util.string import decode, encode
-from quodlibet.util.uri import URI
+from quodlibet.util import print_w
 from quodlibet.qltk.views import AllTreeView
 from quodlibet.qltk.searchbar import SearchBarBox
 from quodlibet.qltk.completion import LibraryTagCompletion
-from quodlibet.qltk.x import MenuItem, Alignment, ScrolledWindow
-from quodlibet.qltk.x import SymbolicIconImage, SeparatorMenuItem
+from quodlibet.qltk.x import MenuItem, Align, ScrolledWindow
+from quodlibet.qltk.x import SymbolicIconImage
 from quodlibet.qltk.menubutton import MenuButton
 
 STATION_LIST_URL = \
-    "http://bitbucket.org/lazka/quodlibet/downloads/radiolist.bz2"
-STATIONS_FAV = os.path.join(const.USERDIR, "stations")
-STATIONS_ALL = os.path.join(const.USERDIR, "stations_all")
+    "https://bitbucket.org/lazka/quodlibet/downloads/radiolist.bz2"
+STATIONS_FAV = os.path.join(quodlibet.get_user_dir(), "stations")
+STATIONS_ALL = os.path.join(quodlibet.get_user_dir(), "stations_all")
 
 # TODO: - Do the update in a thread
 #       - Ranking: reduce duplicate stations (max 3 URLs per station)
@@ -165,7 +170,7 @@ def ParsePLS(file):
         count += 1
 
     if warnings:
-        qltk.WarningMessage(
+        WarningMessage(
             None, _("Unsupported file type"),
             _("Station lists can only contain locations of stations, "
               "not other station lists or playlists. The following locations "
@@ -196,7 +201,8 @@ def ParseM3U(fileobj):
 
 
 def add_station(uri):
-    """Fetches the URI content and extracts IRFiles"""
+    """Fetches the URI content and extracts IRFiles
+    Returns None in error, else a possibly filled list of stations"""
 
     irfs = []
     if isinstance(uri, unicode):
@@ -204,14 +210,19 @@ def add_station(uri):
 
     if uri.lower().endswith(".pls") or uri.lower().endswith(".m3u"):
         try:
-            sock = urllib.urlopen(uri)
-        except EnvironmentError, e:
+            sock = urlopen(uri)
+        except EnvironmentError as e:
+            print_d("Got %s from %s" % (uri, e))
+            encoding = util.get_locale_encoding()
             try:
-                err = e.strerror.decode(const.ENCODING, 'replace')
-            except (TypeError, AttributeError):
-                err = e.strerror[1].decode(const.ENCODING, 'replace')
-            qltk.ErrorMessage(None, _("Unable to add station"), err).run()
-            return []
+                err = e.strerror.decode(encoding, 'replace')
+            except TypeError:
+                err = e.strerror[1].decode(encoding, 'replace')
+            except AttributeError:
+                # Give up and display the exception - may be useful HTTP info
+                err = str(e)
+            ErrorMessage(None, _("Unable to add station"), escape(err)).run()
+            return None
 
         if uri.lower().endswith(".pls"):
             irfs = ParsePLS(sock)
@@ -222,8 +233,8 @@ def add_station(uri):
     else:
         try:
             irfs = [IRFile(uri)]
-        except ValueError, err:
-            qltk.ErrorMessage(None, _("Unable to add station"), err).run()
+        except ValueError as err:
+            ErrorMessage(None, _("Unable to add station"), err).run()
 
     return irfs
 
@@ -239,8 +250,8 @@ def download_taglist(callback, cofuncid, step=1024 * 10):
             task.copool(cofuncid)
 
         try:
-            response = urllib2.urlopen(STATION_LIST_URL)
-        except urllib2.URLError:
+            response = urlopen(STATION_LIST_URL)
+        except EnvironmentError:
             GLib.idle_add(callback, None)
             return
 
@@ -332,18 +343,14 @@ class AddNewStation(GetStringDialog):
         super(AddNewStation, self).__init__(
             parent, _("New Station"),
             _("Enter the location of an Internet radio station:"),
-            okbutton=Gtk.STOCK_ADD)
+            button_label=_("_Add"), button_icon=Icons.LIST_ADD)
 
     def _verify_clipboard(self, text):
         # try to extract a URI from the clipboard
         for line in text.splitlines():
             line = line.strip()
 
-            try:
-                URI(line)
-            except ValueError:
-                pass
-            else:
+            if uri_is_valid(line):
                 return line
 
 
@@ -451,26 +458,14 @@ class QuestionBar(Gtk.InfoBar):
         content.add(label)
 
         self.add_button(_("_Load Stations"), self.RESPONSE_LOAD)
-
-        try:
-            self.set_show_close_button(True)
-        except AttributeError:
-            # < gtk3.10
-            action = self.get_action_area()
-            close_button = CloseButton()
-            close_button.show()
-            self.add_action_widget(close_button, Gtk.ResponseType.CLOSE)
-            # FIXME: doesn't seem to have any effect
-            action.set_child_packing(
-                close_button, False, True, 2, Gtk.PackType.START)
+        self.set_show_close_button(True)
 
     def __response(self, bar, response_id):
         if response_id == Gtk.ResponseType.CLOSE:
             bar.hide()
 
 
-class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
-    __gsignals__ = Browser.__gsignals__
+class InternetRadio(Browser, util.InstanceTracker):
 
     __stations = None
     __fav_stations = None
@@ -480,11 +475,13 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
 
     name = _("Internet Radio")
     accelerated_name = _("_Internet Radio")
+    keys = ["InternetRadio"]
     priority = 16
+    uses_main_library = False
     headers = "title artist ~people grouping genre website ~format " \
         "channel-mode".split()
 
-    TYPE, STOCK, KEY, NAME = range(4)
+    TYPE, ICON_NAME, KEY, NAME = range(4)
     TYPE_FILTER, TYPE_ALL, TYPE_FAV, TYPE_SEP, TYPE_NOCAT = range(5)
     STAR = ["artist", "title", "website", "genre", "comment"]
 
@@ -526,8 +523,9 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         if not self.instances():
             self._destroy()
 
-    def __init__(self, library, main):
+    def __init__(self, library):
         super(InternetRadio, self).__init__(spacing=12)
+        self.set_orientation(Gtk.Orientation.VERTICAL)
 
         if not self.instances():
             self._init(library)
@@ -539,25 +537,25 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         self.accelerators = Gtk.AccelGroup()
         self.__searchbar = search = SearchBarBox(completion=completion,
                                                  accel_group=self.accelerators)
-        gobject_weak(search.connect, 'query-changed', self.__filter_changed)
+        search.connect('query-changed', self.__filter_changed)
 
         menu = Gtk.Menu()
-        new_item = MenuItem(_("_New Station..."), Gtk.STOCK_ADD)
-        gobject_weak(new_item.connect, 'activate', self.__add)
+        new_item = MenuItem(_(u"_New Station…"), Icons.LIST_ADD)
+        new_item.connect('activate', self.__add)
         menu.append(new_item)
-        update_item = MenuItem(_("_Update Stations"), Gtk.STOCK_REFRESH)
-        gobject_weak(update_item.connect, 'activate', self.__update)
+        update_item = MenuItem(_("_Update Stations"), Icons.VIEW_REFRESH)
+        update_item.connect('activate', self.__update)
         menu.append(update_item)
         menu.show_all()
 
         button = MenuButton(
-            SymbolicIconImage("emblem-system", Gtk.IconSize.MENU),
+            SymbolicIconImage(Icons.EMBLEM_SYSTEM, Gtk.IconSize.MENU),
             arrow=True)
         button.set_menu(menu)
 
         def focus(widget, *args):
             qltk.get_top_parent(widget).songlist.grab_focus()
-        gobject_weak(search.connect, 'focus-out', focus, parent=self)
+        search.connect('focus-out', focus)
 
         # treeview
         scrolled_window = ScrolledWindow()
@@ -571,19 +569,19 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         scrolled_window.add(view)
         model = Gtk.ListStore(int, str, str, str)
 
-        model.append(row=[self.TYPE_ALL, Gtk.STOCK_DIRECTORY, "__all",
+        model.append(row=[self.TYPE_ALL, Icons.FOLDER, "__all",
                           _("All Stations")])
-        model.append(row=[self.TYPE_SEP, Gtk.STOCK_DIRECTORY, "", ""])
+        model.append(row=[self.TYPE_SEP, Icons.FOLDER, "", ""])
         #Translators: Favorite radio stations
-        model.append(row=[self.TYPE_FAV, Gtk.STOCK_DIRECTORY, "__fav",
+        model.append(row=[self.TYPE_FAV, Icons.FOLDER, "__fav",
                           _("Favorites")])
-        model.append(row=[self.TYPE_SEP, Gtk.STOCK_DIRECTORY, "", ""])
+        model.append(row=[self.TYPE_SEP, Icons.FOLDER, "", ""])
 
         filters = self.filters
         for text, k in sorted([(filters.text(k), k) for k in filters.keys()]):
-            model.append(row=[self.TYPE_FILTER, Gtk.STOCK_FIND, k, text])
+            model.append(row=[self.TYPE_FILTER, Icons.EDIT_FIND, k, text])
 
-        model.append(row=[self.TYPE_NOCAT, Gtk.STOCK_DIRECTORY,
+        model.append(row=[self.TYPE_NOCAT, Icons.FOLDER,
                           "nocat", _("No Category")])
 
         def separator(model, iter, data):
@@ -601,7 +599,7 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         renderpb = Gtk.CellRendererPixbuf()
         renderpb.props.xpad = 3
         column.pack_start(renderpb, False)
-        column.add_attribute(renderpb, "stock_id", self.STOCK)
+        column.add_attribute(renderpb, "icon-name", self.ICON_NAME)
 
         render = Gtk.CellRendererText()
         render.set_property('ellipsize', Pango.EllipsizeMode.END)
@@ -614,16 +612,13 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         # selection
         selection = view.get_selection()
         selection.set_mode(Gtk.SelectionMode.MULTIPLE)
-        self.__changed_sig = gobject_weak(selection.connect, 'changed',
-            util.DeferredSignal(lambda x: self.activate()), parent=view)
+        self.__changed_sig = connect_destroy(selection, 'changed',
+            util.DeferredSignal(lambda x: self.activate()))
 
         box = Gtk.HBox(spacing=6)
         box.pack_start(search, True, True, 0)
         box.pack_start(button, False, True, 0)
-        if main:
-            self._searchbox = Alignment(box, left=0, right=6, top=6)
-        else:
-            self._searchbox = box
+        self._searchbox = Align(box, left=0, right=6, top=6)
         self._searchbox.show_all()
 
         def qbar_response(infobar, response_id):
@@ -635,7 +630,7 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         if self._is_library_empty():
             self.qbar.show()
 
-        pane = qltk.RHPaned()
+        pane = qltk.ConfigRHPaned("browsers", "internetradio_pos", 0.4)
         pane.show()
         pane.pack1(scrolled_window, resize=False, shrink=False)
         songbox = Gtk.VBox(spacing=6)
@@ -735,9 +730,7 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
         self.__stations.add(to_add)
 
     def __filter_changed(self, bar, text, restore=False):
-        self.__filter = None
-        if not Query.match_all(text):
-            self.__filter = Query(text, self.STAR)
+        self.__filter = Query(text, self.STAR)
 
         if not restore:
             self.activate()
@@ -806,29 +799,26 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
 
     def __add_station(self, uri):
         irfs = add_station(uri)
-
+        if irfs is None:
+            # Error, rather than empty list
+            return
         if not irfs:
-            qltk.ErrorMessage(
+            ErrorMessage(
                 None, _("No stations found"),
                 _("No Internet radio stations were found at %s.") %
                 util.escape(uri)).run()
             return
 
-        irfs = filter(lambda station: station not in self.__fav_stations, irfs)
+        irfs = set(irfs) - set(self.__fav_stations)
         if not irfs:
-            qltk.WarningMessage(
+            WarningMessage(
                 None, _("Unable to add station"),
                 _("All stations listed are already in your library.")).run()
 
         if irfs:
             self.__fav_stations.add(irfs)
 
-    def Menu(self, songs, songlist, library):
-        menu = SongsMenu(self.__librarian, songs, playlists=False, remove=True,
-                         queue=False, devices=False, parent=self)
-
-        menu.prepend(SeparatorMenuItem())
-
+    def Menu(self, songs, library, items):
         in_fav = False
         in_all = False
         for song in songs:
@@ -839,18 +829,19 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
             if in_fav and in_all:
                 break
 
-        button = MenuItem(_("Remove from Favorites"), Gtk.STOCK_REMOVE)
-        button.set_sensitive(in_fav)
-        gobject_weak(button.connect_object, 'activate',
-                     self.__remove_fav, songs)
-        menu.prepend(button)
-
-        button = MenuItem(_("Add to Favorites"), Gtk.STOCK_ADD)
+        iradio_items = []
+        button = MenuItem(_("Add to Favorites"), Icons.LIST_ADD)
         button.set_sensitive(in_all)
-        gobject_weak(button.connect_object, 'activate',
-                     self.__add_fav, songs)
-        menu.prepend(button)
+        connect_obj(button, 'activate', self.__add_fav, songs)
+        iradio_items.append(button)
+        button = MenuItem(_("Remove from Favorites"), Icons.LIST_REMOVE)
+        button.set_sensitive(in_fav)
+        connect_obj(button, 'activate', self.__remove_fav, songs)
+        iradio_items.append(button)
 
+        items.append(iradio_items)
+        menu = SongsMenu(self.__librarian, songs, playlists=False, remove=True,
+                         queue=False, devices=False, items=items)
         return menu
 
     def restore(self):
@@ -875,26 +866,32 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
 
     def __get_filter(self):
         filter_ = self.__get_selection_filter()
+        text_filter = self.__filter or Query("")
 
         if filter_:
-            if self.__filter:
-                filter_ &= self.__filter
+            filter_ &= text_filter
         else:
-            filter_ = self.__filter
+            filter_ = text_filter
 
         return filter_
 
+    def can_filter_text(self):
+        return True
+
+    def filter_text(self, text):
+        self.__searchbar.set_text(text)
+        if Query.is_parsable(text):
+            self.__filter_changed(self.__searchbar, text)
+            self.activate()
+
+    def get_filter_text(self):
+        return self.__searchbar.get_text()
+
     def activate(self):
         filter_ = self.__get_filter()
         libs = self.__get_selected_libraries()
-        songs = itertools.chain(*libs)
-
-        if filter_:
-            songs = filter(filter_.search, songs)
-        else:
-            songs = list(songs)
-
-        self.emit('songs-selected', songs, None)
+        songs = filter_.filter(itertools.chain(*libs))
+        self.songs_selected(songs)
 
     def active_filter(self, song):
         for lib in self.__get_selected_libraries():
@@ -933,11 +930,12 @@ class InternetRadio(Gtk.VBox, Browser, util.InstanceTracker):
             # in case nothing matches, select all
             path = (0,)
 
-        self.view.scroll_to_cell(path, use_align=True, row_align=0.5)
         self.view.set_cursor(path)
+        self.view.scroll_to_cell(path, use_align=True, row_align=0.5)
 
-    def statusbar(self, i):
-        return ngettext("%(count)d station", "%(count)d stations", i)
+    def status_text(self, count, time=None):
+        return (ngettext("%(count)d station", "%(count)d stations", count)
+                % {'count': count})
 
 
 from quodlibet import app
