@@ -1,5 +1,9 @@
 # -*- coding: utf-8 -*-
-# Constants used in various parts of QL, mostly strings.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
+"""Constants used in various parts of QL, mostly strings."""
 
 import sys
 import os
@@ -8,10 +12,11 @@ import os
 class Version(tuple):
     """Represent the version of a dependency as a tuple"""
 
-    def __new__(cls, *args):
-        # Support tuple or varargs instantiation
-        value = args[0] if len(args) == 1 else args
-        return tuple.__new__(Version, value)
+    def __new__(cls, name, *args, **kwargs):
+        inst = tuple.__new__(Version, args)
+        inst.name = name
+        inst.message = kwargs.pop("message", "")
+        return inst
 
     def human_version(self):
         return ".".join(map(str, self))
@@ -19,22 +24,40 @@ class Version(tuple):
     def __str__(self):
         return self.human_version()
 
+    def check(self, version_tuple):
+        """Raises ImportError if the version isn't supported"""
+
+        if self[0] == version_tuple[0] and version_tuple >= self:
+            return
+        message = " " + self.message if self.message else ""
+        raise ImportError("%s %s required. %s found.%s" % (
+            self.name, self, Version("", *version_tuple), message))
+
 
 class MinVersions(object):
     """Dependency requirements for Quod Libet / Ex Falso"""
-    PYTHON = Version(2, 7)
-    MUTAGEN = Version(1, 27)
 
-VERSION_TUPLE = Version(3, 5, 3)
+    PYTHON2 = Version("Python2", 2, 7)
+    PYTHON3 = Version("Python3", 3, 4)
+    MUTAGEN = Version("Mutagen", 1, 32,
+        message="Use the Quod Libet unstable PPAs/repos to get a newer "
+                "mutagen version.")
+    GTK = Version("GTK+", 3, 10)
+    PYGOBJECT = Version("PyGObject", 3, 12)
+    GSTREAMER = Version("GStreamer", 1, 0)
+
+
+VERSION_TUPLE = Version("", 3, 7, 1)
 VERSION = str(VERSION_TUPLE)
 
 # entry point for the user guide / wiki
-BRANCH_NAME = "quodlibet-3.5"
+BRANCH_NAME = "quodlibet-3.7"
 DOCS_BASE_URL = "https://quodlibet.readthedocs.org/en/%s"
 DOCS_LATEST = DOCS_BASE_URL % "latest"
 DOCS_BASE_URL %= BRANCH_NAME if BRANCH_NAME != "master" else "latest"
 ONLINE_HELP = DOCS_BASE_URL + "/guide/index.html"
 SEARCH_HELP = DOCS_BASE_URL + "/guide/searching.html"
+SHORTCUTS_HELP = DOCS_BASE_URL + "/guide/shortcuts.html"
 
 # Email used as default for reading/saving per-user data in tags, etc.
 EMAIL = os.environ.get("EMAIL", "quodlibet@lists.sacredchao.net")
@@ -42,7 +65,7 @@ EMAIL = os.environ.get("EMAIL", "quodlibet@lists.sacredchao.net")
 # Displayed as registered / help email address
 SUPPORT_EMAIL = "quod-libet-development@googlegroups.com"
 
-MAIN_AUTHORS = """\
+MAIN_AUTHORS = u"""\
 Joe Wreschnig
 Michael Urman
 Iñigo Serna
@@ -52,14 +75,15 @@ Nick Boultbee""".split("\n")
 
 # about dialog, --version etc.
 WEBSITE = "https://quodlibet.readthedocs.org/"
-COPYRIGHT = """Copyright © 2004-2015 %s...""" % ", ".join(MAIN_AUTHORS)
+COPYRIGHT = u"""Copyright © 2004-2016 %s...""" % u", ".join(MAIN_AUTHORS)
 
-AUTHORS = sorted("""\
+AUTHORS = sorted(u"""\
 Alexandre Passos
 Alexey Bobyakov
 Alex Geoffrey Smith
 Anders Carlsson
 Andreas Bombe
+Andrew Chadwick
 Anton Shestakov
 Ari Pollak
 Aymeric Mansoux
@@ -67,6 +91,7 @@ Bastian Kleineidam
 Bastien Gorissen
 Benjamin Boutier
 Ben Zeigler
+Bernd Wechner
 Bruno Bergot
 Carlo Teubner
 Christine Spang
@@ -85,6 +110,7 @@ Guillaume Chazarain
 Hans Scholze
 Iñigo Serna
 Jacob Lee
+Jakob Gahde
 Jan Arne Petersen
 Jan Path
 Javier Kohen
@@ -127,10 +153,11 @@ Tomasz Torcz
 Tshepang Lekhonkhobe
 Türerkan İnce
 Vasiliy Faronov
+Victoria Hayes
 Zack Weinberg
 """.strip().split("\n"))
 
-TRANSLATORS = sorted("""
+TRANSLATORS = sorted(u"""
 Alexandre Passos (pt)
 Andreas Bertheussen (nb)
 Anton Shestakov (ru)
@@ -158,6 +185,7 @@ Johám-Luís Miguéns Vila (es, gl, gl_ES, eu, pt)
 Jonas Slivka (lt)
 Joshua Kwan (fr)
 Luca Baraldi (it)
+Ludovic Druette (fr)
 Lukáš Lalinský (sk)
 Mathieu Morey (fr)
 Michal Nowikowski (pl)
@@ -184,7 +212,7 @@ Yasushi Iwata (ja)
 Сергей Федосеев (ru)
 """.strip().splitlines())
 
-ARTISTS = sorted("""\
+ARTISTS = sorted(u"""\
 Tobias
 Jakub Steiner
 Fabien Devaux
