@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2011,2013 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -17,6 +18,7 @@ from xml.dom.minidom import parseString
 
 from gi.repository import GLib
 
+from quodlibet.util import print_w
 from .util import get_api_key, GateKeeper
 
 
@@ -25,7 +27,7 @@ gatekeeper = GateKeeper(requests_per_sec=3)
 
 
 class AcoustidSubmissionThread(threading.Thread):
-    URL = "http://api.acoustid.org/v2/submit"
+    URL = "https://api.acoustid.org/v2/submit"
     SONGS_PER_SUBMISSION = 50
     TIMEOUT = 10.0
 
@@ -256,7 +258,7 @@ def parse_acoustid_response(json_data):
 
 
 class AcoustidLookupThread(threading.Thread):
-    URL = "http://api.acoustid.org/v2/lookup"
+    URL = "https://api.acoustid.org/v2/lookup"
     MAX_SONGS_PER_SUBMISSION = 5
     TIMEOUT = 10.0
 
