@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman
-#           2012-2014 Nick Boultbee
+#           2012-2016 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -16,18 +16,23 @@ import time
 
 from quodlibet import util
 from quodlibet import config
-from quodlibet.util.path import mkdir, fsdecode, mtime, expanduser, is_fsnative
-from quodlibet.util.path import normalize_path, fsnative, escape_filename
+from quodlibet.util.path import mkdir, fsdecode, mtime, expanduser, \
+    is_fsnative, normalize_path, fsnative, escape_filename, uri_from_path
 from quodlibet.util.string import encode, decode, isascii
 
-from quodlibet.util.uri import URI
+from quodlibet.util import iso639
 from quodlibet.util import human_sort_key as human, capitalize
 
 from quodlibet.util.tags import TAG_ROLES, TAG_TO_SORT
+from quodlibet.compat import iteritems, string_types, text_type, \
+    number_types, listitems, izip_longest, integer_types
 
 from ._image import ImageContainer
+from ._misc import AudioFileError, translate_errors
 
 
+translate_errors
+
 MIGRATE = {"~#playcount", "~#laststarted", "~#lastplayed", "~#added",
            "~#skipcount", "~#rating", "~bookmark"}
 """These get migrated if a song gets reloaded"""
@@ -36,14 +41,22 @@ PEOPLE = ["artist", "albumartist", "author", "composer", "~performers",
           "originalartist", "lyricist", "arranger", "conductor"]
 """Sources of the ~people tag, most important first"""
 
-INTERN_NUM_DEFAULT = {"~#lastplayed", "~#laststarted", "~#playcount",
-                      "~#skipcount", "~#length", "~#bitrate", "~#filesize"}
-"""Default to 0"""
+TIME_TAGS = {"~#lastplayed", "~#laststarted", "~#added", "~#mtime"}
+"""Time in seconds since epoch, defaults to 0"""
+
+SIZE_TAGS = {"~#filesize"}
+"""Size in bytes, defaults to 0"""
+
+NUMERIC_ZERO_DEFAULT = {"~#skipcount", "~#playcount", "~#length", "~#bitrate"}
+"""Defaults to 0"""
+
+NUMERIC_ZERO_DEFAULT.update(TIME_TAGS)
+NUMERIC_ZERO_DEFAULT.update(SIZE_TAGS)
 
 FILESYSTEM_TAGS = {"~filename", "~basename", "~dirname"}
 """Values are bytes in Linux instead of unicode"""
 
-SORT_TO_TAG = dict([(v, k) for (k, v) in TAG_TO_SORT.iteritems()])
+SORT_TO_TAG = dict([(v, k) for (k, v) in iteritems(TAG_TO_SORT)])
 """Reverse map, so sort tags can fall back to the normal ones"""
 
 PEOPLE_SORT = [TAG_TO_SORT.get(k, k) for k in PEOPLE]
@@ -60,13 +73,13 @@ def decode_value(tag, value):
     Not reversible.
     """
 
-    if isinstance(value, unicode):
+    if isinstance(value, text_type):
         return value
     elif isinstance(value, float):
         return u"%.2f" % value
     elif tag in FILESYSTEM_TAGS:
         return fsdecode(value)
-    return unicode(value)
+    return text_type(value)
 
 
 class AudioFile(dict, ImageContainer):
@@ -85,21 +98,30 @@ class AudioFile(dict, ImageContainer):
     their description.
     """
 
-    # New tags received from the backend will update the song
     fill_metadata = False
-    # New song duration from the backend will update the song
+    """New tags received from the backend will update the song"""
+
     fill_length = False
-    # Container for multiple songs, while played new songs can start/end
+    """New song duration from the backend will update the song"""
+
     multisong = False
-    # Part of a multisong
+    """Is a container for multiple songs
+     i.e. while played new songs can start / end"""
+
     streamsong = False
-    # Can be added to the queue, playlists
+    """Is part of a multisong"""
+
     can_add = True
-    # Is a real file
+    """Can be added to the queue, playlists"""
+
     is_file = True
+    """Is a real (local) file"""
 
     format = "Unknown Audio File"
+    """The underlying file format"""
+
     mimes = []
+    """MIME types this class can represent"""
 
     def __song_key(self):
         return (self("~#disc"), self("~#track"),
@@ -145,9 +167,20 @@ class AudioFile(dict, ImageContainer):
         pass
 
     def __setitem__(self, key, value):
-        dict.__setitem__(self, key, value)
         if not self.__dict__:
+            # unpickle case.. we can't fail
+            dict.__setitem__(self, key, value)
             return
+
+        if key.startswith("~#"):
+            assert isinstance(value, number_types)
+        elif key in FILESYSTEM_TAGS:
+            assert is_fsnative(value)
+        else:
+            value = text_type(value)
+
+        dict.__setitem__(self, key, value)
+
         pop = self.__dict__.pop
         pop("album_key", None)
         pop("sort_key", None)
@@ -168,14 +201,6 @@ class AudioFile(dict, ImageContainer):
     def mountpoint(self):
         return self["~mountpoint"]
 
-    def __cmp__(self, other):
-        if not other:
-            return -1
-        try:
-            return cmp(self.sort_key, other.sort_key)
-        except AttributeError:
-            return -1
-
     def __hash__(self):
         # Dicts aren't hashable by default, so we need a hash
         # function. Previously this used ~filename. That created a
@@ -187,13 +212,21 @@ class AudioFile(dict, ImageContainer):
         # And to preserve Python hash rules, we need a strict __eq__.
         return self is other
 
+    def __lt__(self, other):
+        return self.sort_key < other.sort_key
+
     def __ne__(self, other):
         return self is not other
 
     def reload(self):
-        """Reload an audio file from disk. The caller is responsible for
-        handling any errors."""
+        """Reload an audio file from disk. If reloading fails nothing will
+        change.
 
+        Raises:
+            AudioFileError: if the file fails to load
+        """
+
+        backup = dict(self)
         fn = self["~filename"]
         saved = {}
         for key in self:
@@ -201,8 +234,13 @@ class AudioFile(dict, ImageContainer):
                 saved[key] = self[key]
         self.clear()
         self["~filename"] = fn
-        self.__init__(fn)
-        self.update(saved)
+        try:
+            self.__init__(fn)
+        except AudioFileError:
+            self.update(backup)
+            raise
+        else:
+            self.update(saved)
 
     def realkeys(self):
         """Returns a list of keys that are not internal, i.e. they don't
@@ -226,7 +264,7 @@ class AudioFile(dict, ImageContainer):
         return "\n".join(self.list_unique(sorted(self.prefixkeys(tag))))
 
     def iterrealitems(self):
-        return ((k, v) for (k, v) in self.iteritems() if k[:1] != "~")
+        return ((k, v) for (k, v) in iteritems(self) if k[:1] != "~")
 
     def __call__(self, key, default=u"", connector=" - "):
         """Return a key, synthesizing it if necessary. A default value
@@ -312,7 +350,7 @@ class AudioFile(dict, ImageContainer):
                 try:
                     return self["~uri"]
                 except KeyError:
-                    return URI.frompath(self["~filename"])
+                    return text_type(uri_from_path(self["~filename"]))
             elif key == "format":
                 return self.get("~format", self.format)
             elif key == "codec":
@@ -325,6 +363,11 @@ class AudioFile(dict, ImageContainer):
                                [self.get("~encoding"), self.get("encodedby")])
                 encoding = u"\n".join(parts)
                 return encoding or default
+            elif key == "language":
+                codes = self.list("language")
+                if not codes:
+                    return default
+                return u"\n".join(iso639.translate(c) or c for c in codes)
             elif key == "bitrate":
                 return util.format_bitrate(self("~#bitrate"))
             elif key == "#date":
@@ -357,8 +400,16 @@ class AudioFile(dict, ImageContainer):
                 except (ValueError, IndexError, TypeError, KeyError):
                     return default
             elif key == "lyrics":
+                # First, try the embedded lyrics.
                 try:
-                    fileobj = file(self.lyric_filename, "rU")
+                    return self[key]
+                except KeyError:
+                    pass
+
+                # If there are no embedded lyrics, try to read them from
+                # the external file.
+                try:
+                    fileobj = open(self.lyric_filename, "rU")
                 except EnvironmentError:
                     return default
                 else:
@@ -381,8 +432,8 @@ class AudioFile(dict, ImageContainer):
                 key = "~" + key
                 if key in self:
                     return self[key]
-                elif key in INTERN_NUM_DEFAULT:
-                    return dict.get(self, key, 0)
+                elif key in NUMERIC_ZERO_DEFAULT:
+                    return 0
                 else:
                     try:
                         val = self[key[2:]]
@@ -464,6 +515,20 @@ class AudioFile(dict, ImageContainer):
             expanduser(fsnative(u"~/.lyrics")), sub_dir, filename)
         return path
 
+    @property
+    def has_rating(self):
+        """True if the song has a rating set.
+
+        In case this is False song('~#rating') would return the default value
+        """
+
+        return self.get("~#rating") is not None
+
+    def remove_rating(self):
+        """Removes the set rating so the default will be returned"""
+
+        self.pop("~#rating", None)
+
     def comma(self, key):
         """Get all values of a tag, separated by commas. Synthetic
         tags are supported, but will be slower. All list items
@@ -479,7 +544,7 @@ class AudioFile(dict, ImageContainer):
         else:
             v = self.get(key, u"")
 
-        if isinstance(v, (int, long, float)):
+        if isinstance(v, number_types):
             return v
         else:
             return v.replace("\n", ", ")
@@ -505,26 +570,40 @@ class AudioFile(dict, ImageContainer):
             v = self.get(key)
             return [] if v is None else v.split("\n")
 
-    def list_separate(self, key, connector=" - "):
-        """Similar to list, but will return a list of all combinations
-        for tied tags instead of one comma separated string.
+    def list_sort(self, key):
+        """Like list but return display,sort pairs when appropriate
+        and work on all tags.
 
-        In case of tied tags the result will be unicode, otherwise
-        it returns the same as list()
+        In case no sort value exists the display one is returned. The sort
+        value is only an empty string if the display one is empty as well.
         """
 
-        if key[:1] == "~" and "~" in key[1:]:
-            vals = []
-            for v in map(self.__call__, util.tagsplit(key)):
-                v = decode_value(key, v)
-                if v:
-                    vals.append(v.split("\n"))
-            r = [[]]
-            for x in vals:
-                r = [i + [y] for y in x for i in r]
-            return map(connector.join, r)
+        display = decode_value(key, self(key))
+        display = display.split("\n") if display else []
+        sort = []
+        if key in TAG_TO_SORT:
+            sort = decode_value(TAG_TO_SORT[key],
+                                self(TAG_TO_SORT[key]))
+            # it would be better to use something that doesn't fall back
+            # to the key itself, but what?
+            sort = sort.split("\n") if sort else []
+
+        result = []
+        for d, s in izip_longest(display, sort):
+            if d is not None:
+                result.append((d, (s if s is not None and s != "" else d)))
+        return result
+
+    def list_separate(self, key):
+        """For tied tags return the list union of the display,sort values
+           otherwise just do list_sort
+        """
+        if key[:1] == "~" and "~" in key[1:]: # tied tag
+            vals = [self.list_sort(tag) for tag in util.tagsplit(key)]
+            r = [j for i in vals for j in i]
+            return r
         else:
-            return self.list(key)
+            return self.list_sort(key)
 
     def list_unique(self, keys):
         """Returns a combined value of all values in keys; duplicate values
@@ -551,7 +630,7 @@ class AudioFile(dict, ImageContainer):
 
         merged = AudioFile()
         text = {}
-        for key, value in self.iteritems():
+        for key, value in iteritems(self):
             lower = key.lower()
             if key.startswith("~#"):
                 merged[lower] = value
@@ -639,7 +718,7 @@ class AudioFile(dict, ImageContainer):
             elif c.startswith("//www."):
                 return "http:" + cont
         else:
-            text = "http://www.google.com/search?q="
+            text = "https://www.google.com/search?q="
             esc = lambda c: ord(c) > 127 and '%%%x' % ord(c) or c
             if "labelid" in self:
                 text += ''.join(map(esc, self["labelid"]))
@@ -656,14 +735,17 @@ class AudioFile(dict, ImageContainer):
 
     def sanitize(self, filename=None):
         """Fill in metadata defaults. Find ~mountpoint, ~#mtime, ~#filesize
-        and ~#added. Check for null bytes in tags."""
+        and ~#added. Check for null bytes in tags.
+
+        Does not raise.
+        """
 
         # Replace nulls with newlines, trimming zero-length segments
-        for key, val in self.items():
-            if isinstance(val, basestring) and '\0' in val:
+        for key, val in listitems(self):
+            if isinstance(val, string_types) and '\0' in val:
                 self[key] = '\n'.join(filter(lambda s: s, val.split('\0')))
             # Remove unnecessary defaults
-            if key in INTERN_NUM_DEFAULT and val == 0:
+            if key in NUMERIC_ZERO_DEFAULT and val == 0:
                 del self[key]
 
         if filename:
@@ -713,13 +795,13 @@ class AudioFile(dict, ImageContainer):
         """A string of 'key=value' lines, similar to vorbiscomment output."""
 
         def encode_key(k):
-            return encode(k) if isinstance(k, unicode) else k
+            return encode(k) if isinstance(k, text_type) else k
 
         s = []
         for k in self.keys():
             enc_key = encode_key(k)
 
-            if isinstance(self[k], int) or isinstance(self[k], long):
+            if isinstance(self[k], integer_types):
                 s.append("%s=%d" % (enc_key, self[k]))
             elif isinstance(self[k], float):
                 s.append("%s=%f" % (enc_key, self[k]))
@@ -729,7 +811,7 @@ class AudioFile(dict, ImageContainer):
                         s.append("%s=%s" % (enc_key, v2))
                     else:
                         s.append("%s=%s" % (enc_key, encode(v2)))
-        for k in (INTERN_NUM_DEFAULT - set(self.keys())):
+        for k in (NUMERIC_ZERO_DEFAULT - set(self.keys())):
             enc_key = encode_key(k)
             s.append("%s=%d" % (enc_key, self.get(k, 0)))
         if "~#rating" not in self:
@@ -838,7 +920,12 @@ class AudioFile(dict, ImageContainer):
             return min(15, scale)
 
     def write(self):
-        """Write metadata back to the file."""
+        """Write metadata back to the file.
+
+        Raises:
+            AudioFileError: in case writing fails
+        """
+
         raise NotImplementedError
 
     @property
