@@ -6,7 +6,10 @@
 # published by the Free Software Foundation
 
 from mutagen.musepack import Musepack
-from quodlibet.formats._apev2 import APEv2File
+
+from quodlibet.compat import text_type
+from ._audio import translate_errors
+from ._apev2 import APEv2File
 
 
 class MPCFile(APEv2File):
@@ -14,11 +17,16 @@ class MPCFile(APEv2File):
     mimes = ["audio/x-musepack", "audio/x-mpc"]
 
     def __init__(self, filename):
-        audio = Musepack(filename)
+        with translate_errors():
+            audio = Musepack(filename)
+
         super(MPCFile, self).__init__(filename, audio)
-        self["~#length"] = int(audio.info.length)
+        self["~#length"] = audio.info.length
         self["~#bitrate"] = int(audio.info.bitrate / 1000)
 
+        version = audio.info.version
+        self["~codec"] = u"%s SV%d" % (self.format, version)
+
         try:
             if audio.info.title_gain:
                 track_g = u"%+0.2f dB" % audio.info.title_gain
@@ -27,16 +35,16 @@ class MPCFile(APEv2File):
                 album_g = u"%+0.2f dB" % audio.info.album_gain
                 self.setdefault("replaygain_album_gain", album_g)
             if audio.info.title_peak:
-                track_p = unicode(audio.info.title_peak * 2)
+                track_p = text_type(audio.info.title_peak * 2)
                 self.setdefault("replaygain_track_peak", track_p)
             if audio.info.album_peak:
-                album_p = unicode(audio.info.album_peak * 2)
+                album_p = text_type(audio.info.album_peak * 2)
                 self.setdefault("replaygain_album_peak", album_p)
         except AttributeError:
             pass
 
         self.sanitize(filename)
 
-info = MPCFile
+loader = MPCFile
 types = [MPCFile]
 extensions = [".mpc", ".mp+"]
