@@ -8,7 +8,10 @@
 import os
 import wave
 
-from quodlibet.formats._audio import AudioFile
+from quodlibet.util.path import fsdecode
+
+from ._audio import AudioFile, translate_errors
+
 
 extensions = [".wav"]
 
@@ -18,13 +21,16 @@ class WAVEFile(AudioFile):
     mimes = ["audio/wav", "audio/x-wav", "audio/wave"]
 
     def __init__(self, filename):
-        f = wave.open(filename, "rb")
-        self["~#length"] = f.getnframes() // f.getframerate()
+        with translate_errors():
+            with open(filename, "rb") as h:
+                f = wave.open(h)
+                self["~#length"] = float(f.getnframes()) / f.getframerate()
         self.sanitize(filename)
 
     def sanitize(self, filename):
         super(WAVEFile, self).sanitize(filename)
-        self["title"] = os.path.basename(self["~filename"])[:-4]
+        self["title"] = fsdecode(os.path.splitext(
+            os.path.basename(self["~filename"]))[0])
 
     def write(self):
         pass
@@ -35,5 +41,5 @@ class WAVEFile(AudioFile):
         else:
             return k == "artist"
 
-info = WAVEFile
+loader = WAVEFile
 types = [WAVEFile]
