@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman
 #           2009-2014 Christoph Reiter
 #
@@ -10,13 +11,14 @@ import base64
 
 import mutagen
 from mutagen.flac import Picture, error as FLACError
+from mutagen.id3 import ID3
 
 from quodlibet import config
 from quodlibet import const
-from quodlibet.config import RATINGS
 from quodlibet.util.path import get_temp_cover_file
-from quodlibet.formats._audio import AudioFile
-from quodlibet.formats._image import EmbeddedImage, APICType
+
+from ._audio import AudioFile, translate_errors, AudioFileError
+from ._image import EmbeddedImage, APICType
 
 
 # Migrate old layout
@@ -34,12 +36,15 @@ class MutagenVCFile(AudioFile):
         # If we're done a type probe, use the results of that to avoid
         # reopening the file.
         if audio is None:
-            audio = self.MutagenType(filename)
-        self["~#length"] = int(audio.info.length)
+            with translate_errors():
+                audio = self.MutagenType(filename)
+        self["~#length"] = audio.info.length
         try:
             self["~#bitrate"] = int(audio.info.bitrate / 1000)
         except AttributeError:
             pass
+        if audio.tags and audio.tags.vendor:
+            self["~encoding"] = audio.tags.vendor
         # mutagen keys are lower cased
         for key, value in (audio.tags or {}).items():
             self[key] = "\n".join(value)
@@ -108,7 +113,7 @@ class MutagenVCFile(AudioFile):
     def get_images(self):
         try:
             audio = self.MutagenType(self["~filename"])
-        except EnvironmentError:
+        except Exception:
             return []
 
         # metadata_block_picture
@@ -146,14 +151,14 @@ class MutagenVCFile(AudioFile):
 
         try:
             audio = self.MutagenType(self["~filename"])
-        except EnvironmentError:
+        except Exception:
             return None
 
         pictures = []
         for data in audio.get("metadata_block_picture", []):
             try:
                 pictures.append(Picture(base64.b64decode(data)))
-            except (TypeError, FLACError):
+            except (TypeError, FLACError, ValueError):
                 pass
 
         cover = None
@@ -172,7 +177,7 @@ class MutagenVCFile(AudioFile):
         cover = audio.get("coverart")
         try:
             cover = cover and base64.b64decode(cover[0])
-        except TypeError:
+        except (TypeError, ValueError):
             cover = None
 
         if not cover:
@@ -187,29 +192,25 @@ class MutagenVCFile(AudioFile):
     def clear_images(self):
         """Delete all embedded images"""
 
-        if not self.has_images:
-            return
-
-        try:
+        with translate_errors():
             audio = self.MutagenType(self["~filename"])
-        except EnvironmentError:
-            return
-
-        audio.pop("metadata_block_picture", None)
-        audio.pop("coverart", None)
-        audio.pop("coverartmime", None)
-        audio.save()
+            audio.pop("metadata_block_picture", None)
+            audio.pop("coverart", None)
+            audio.pop("coverartmime", None)
+            audio.save()
 
         self.has_images = False
 
     def set_image(self, image):
         """Replaces all embedded images by the passed image"""
 
-        try:
+        with translate_errors():
             audio = self.MutagenType(self["~filename"])
-            data = image.file.read()
-        except EnvironmentError:
-            return
+
+        try:
+            data = image.read()
+        except EnvironmentError as e:
+            raise AudioFileError(e)
 
         pic = Picture()
         pic.data = data
@@ -221,8 +222,11 @@ class MutagenVCFile(AudioFile):
 
         audio.pop("coverart", None)
         audio.pop("coverartmime", None)
-        audio["metadata_block_picture"] = base64.b64encode(pic.write())
-        audio.save()
+        audio["metadata_block_picture"] = base64.b64encode(
+            pic.write()).decode("ascii")
+
+        with translate_errors():
+            audio.save()
 
         self.has_images = True
 
@@ -250,9 +254,8 @@ class MutagenVCFile(AudioFile):
 
         if config.getboolean("editing", "save_to_songs"):
             email = email or const.EMAIL
-            rating = self("~#rating")
-            if rating != RATINGS.default:
-                comments["rating:" + email] = str(rating)
+            if self.has_rating:
+                comments["rating:" + email] = str(self("~#rating"))
             playcount = self.get("~#playcount", 0)
             if playcount != 0:
                 comments["playcount:" + email] = str(playcount)
@@ -283,7 +286,8 @@ class MutagenVCFile(AudioFile):
                 comments[main] = lower.list(fallback)
 
     def write(self):
-        audio = self.MutagenType(self["~filename"])
+        with translate_errors():
+            audio = self.MutagenType(self["~filename"])
         if audio.tags is None:
             audio.add_tags()
 
@@ -298,60 +302,37 @@ class MutagenVCFile(AudioFile):
         self.__prep_write_total(audio.tags,
                                 "disctotal", "totaldiscs", "discnumber")
 
-        audio.save()
+        with translate_errors():
+            audio.save()
         self.sanitize()
 
 extensions = []
 ogg_formats = []
-try:
-    from mutagen.oggvorbis import OggVorbis
-except ImportError:
-    OggVorbis = None
-else:
-    extensions.append(".ogg")
-    extensions.append(".oga")
-    ogg_formats.append(OggVorbis)
 
-try:
-    from mutagen.flac import FLAC, FLACNoHeaderError
-except ImportError:
-    FLAC = None
-else:
-    extensions.append(".flac")
-    ogg_formats.append(FLAC)
+from mutagen.oggvorbis import OggVorbis
+extensions.append(".ogg")
+extensions.append(".oga")
+ogg_formats.append(OggVorbis)
 
-try:
-    from mutagen.oggflac import OggFLAC
-except ImportError:
-    OggFLAC = None
-else:
-    extensions.append(".oggflac")
-    ogg_formats.append(OggFLAC)
+from mutagen.flac import FLAC, FLACNoHeaderError
+extensions.append(".flac")
+ogg_formats.append(FLAC)
 
-try:
-    from mutagen.oggspeex import OggSpeex
-except ImportError:
-    OggSpeex = None
-else:
-    extensions.append(".spx")
-    ogg_formats.append(OggSpeex)
+from mutagen.oggflac import OggFLAC
+extensions.append(".oggflac")
+ogg_formats.append(OggFLAC)
+
+from mutagen.oggspeex import OggSpeex
+extensions.append(".spx")
+ogg_formats.append(OggSpeex)
 
 from mutagen.oggtheora import OggTheora
 extensions.append(".ogv")
 ogg_formats.append(OggTheora)
 
-try:
-    from mutagen.oggopus import OggOpus
-except ImportError:
-    OggOpus = None
-else:
-    extensions.append(".opus")
-    ogg_formats.append(OggOpus)
-
-try:
-    from mutagen.id3 import ID3
-except ImportError:
-    ID3 = None
+from mutagen.oggopus import OggOpus
+extensions.append(".opus")
+ogg_formats.append(OggOpus)
 
 
 class OggFile(MutagenVCFile):
@@ -391,7 +372,8 @@ class FLACFile(MutagenVCFile):
 
     def __init__(self, filename, audio=None):
         if audio is None:
-            audio = FLAC(filename)
+            with translate_errors():
+                audio = FLAC(filename)
         super(FLACFile, self).__init__(filename, audio)
         if audio.pictures:
             self.has_images = True
@@ -401,7 +383,7 @@ class FLACFile(MutagenVCFile):
 
         try:
             tag = FLAC(self["~filename"])
-        except EnvironmentError:
+        except Exception:
             return images
 
         for cover in tag.pictures:
@@ -419,7 +401,7 @@ class FLACFile(MutagenVCFile):
 
         try:
             tag = FLAC(self["~filename"])
-        except EnvironmentError:
+        except Exception:
             return None
 
         covers = tag.pictures
@@ -437,13 +419,10 @@ class FLACFile(MutagenVCFile):
     def clear_images(self):
         """Delete all embedded images"""
 
-        try:
+        with translate_errors():
             tag = FLAC(self["~filename"])
-        except EnvironmentError:
-            return
-
-        tag.clear_pictures()
-        tag.save()
+            tag.clear_pictures()
+            tag.save()
 
         # clear vcomment tags
         super(FLACFile, self).clear_images()
@@ -453,11 +432,13 @@ class FLACFile(MutagenVCFile):
     def set_image(self, image):
         """Replaces all embedded images by the passed image"""
 
-        try:
+        with translate_errors():
             tag = FLAC(self["~filename"])
-            data = image.file.read()
-        except EnvironmentError:
-            return
+
+        try:
+            data = image.read()
+        except EnvironmentError as e:
+            raise AudioFileError(e)
 
         pic = Picture()
         pic.data = data
@@ -468,7 +449,9 @@ class FLACFile(MutagenVCFile):
         pic.depth = image.color_depth
 
         tag.add_picture(pic)
-        tag.save()
+
+        with translate_errors():
+            tag.save()
 
         # clear vcomment tags
         super(FLACFile, self).clear_images()
@@ -477,30 +460,36 @@ class FLACFile(MutagenVCFile):
 
     def write(self):
         if ID3 is not None:
-            ID3().delete(filename=self["~filename"])
+            with translate_errors():
+                ID3().delete(filename=self["~filename"])
         super(FLACFile, self).write()
 
 types = []
-for var in globals().values():
+for var in list(globals().values()):
     if getattr(var, 'MutagenType', None):
         types.append(var)
 
 
-def info(filename):
-    try:
+def loader(filename):
+    """
+    Returns:
+        AudioFile
+    Raises:
+        AudioFileError
+    """
+
+    with translate_errors():
         audio = mutagen.File(filename, options=ogg_formats)
-    except AttributeError:
-        audio = OggVorbis(filename)
-    if audio is None and FLAC is not None:
-        # FLAC with ID3
-        try:
-            audio = FLAC(filename)
-        except FLACNoHeaderError:
-            pass
-    if audio is None:
-        raise IOError("file type could not be determined")
-    Kind = type(audio)
-    for klass in globals().values():
-        if Kind is getattr(klass, 'MutagenType', None):
-            return klass(filename, audio)
-    raise IOError("file type could not be determined")
+        if audio is None and FLAC is not None:
+            # FLAC with ID3
+            try:
+                audio = FLAC(filename)
+            except FLACNoHeaderError:
+                pass
+        if audio is None:
+            raise AudioFileError("file type could not be determined")
+        Kind = type(audio)
+        for klass in globals().values():
+            if Kind is getattr(klass, 'MutagenType', None):
+                return klass(filename, audio)
+        raise AudioFileError("file type could not be determined")
