@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright 2005-2011 Joe Wreschnig, Michael Urman, Christoph Reiter,
 #                     Nick Boultbee
 #
@@ -11,7 +12,9 @@ from gi.repository import Gtk, Pango, GObject
 
 from quodlibet import qltk
 from quodlibet.qltk.views import RCMHintedTreeView
+from quodlibet.util import connect_obj
 from quodlibet.qltk import entry
+from quodlibet.qltk import Icons
 
 
 class _KeyValueEditor(qltk.Window):
@@ -48,7 +51,7 @@ class _KeyValueEditor(qltk.Window):
         l.set_alignment(0.0, 0.5)
         t.attach(l, 0, 1, 1, 2, xoptions=Gtk.AttachOptions.FILL)
         t.attach(self.value, 1, 2, 1, 2)
-        add = Gtk.Button(stock=Gtk.STOCK_ADD)
+        add = qltk.Button(_("_Add"), Icons.LIST_ADD)
         add.set_sensitive(False)
         t.attach(add, 2, 3, 1, 2, xoptions=Gtk.AttachOptions.FILL)
 
@@ -75,32 +78,36 @@ class _KeyValueEditor(qltk.Window):
         self.get_child().pack_start(sw, True, True, 0)
 
         menu = Gtk.Menu()
-        remove = Gtk.ImageMenuItem(label=Gtk.STOCK_REMOVE, use_stock=True)
-        remove.connect_object('activate', self.__remove, view)
+        remove = qltk.MenuItem(_("_Remove"), Icons.LIST_REMOVE)
+        connect_obj(remove, 'activate', self.__remove, view)
         qltk.add_fake_accel(remove, "Delete")
         menu.append(remove)
         menu.show_all()
 
         bbox = Gtk.HButtonBox()
-        rem_b = Gtk.Button(stock=Gtk.STOCK_REMOVE)
+        rem_b = qltk.Button(_("_Remove"), Icons.LIST_REMOVE)
         rem_b.set_sensitive(False)
         bbox.pack_start(rem_b, True, True, 0)
-        close = Gtk.Button(stock=Gtk.STOCK_CLOSE)
-        bbox.pack_start(close, True, True, 0)
+        self.use_header_bar()
+        close = qltk.Button(_("_Close"), Icons.WINDOW_CLOSE)
+        if not self.has_close_button():
+            bbox.pack_start(close, True, True, 0)
+        else:
+            bbox.set_layout(Gtk.ButtonBoxStyle.START)
         self.get_child().pack_start(bbox, False, True, 0)
 
         selection = view.get_selection()
-        name.connect_object('activate', Gtk.Entry.grab_focus, self.value)
-        self.value.connect_object('activate', Gtk.Button.clicked, add)
+        connect_obj(name, 'activate', Gtk.Entry.grab_focus, self.value)
+        connect_obj(self.value, 'activate', Gtk.Button.clicked, add)
         self.value.connect('changed', self.__changed, [add])
-        add.connect_object(
+        connect_obj(add,
             'clicked', self.__add, selection, name, self.value, self.model)
         selection.connect('changed', self.__set_text, name, self.value, rem_b)
         view.connect('popup-menu', self.__popup, menu)
-        rem_b.connect_object('clicked', self.__remove, view)
-        close.connect_object('clicked', qltk.Window.destroy, self)
+        connect_obj(rem_b, 'clicked', self.__remove, view)
+        connect_obj(close, 'clicked', qltk.Window.destroy, self)
         view.connect('key-press-event', self.__view_key_press)
-        self.connect_object('destroy', Gtk.Menu.destroy, menu)
+        connect_obj(self, 'destroy', Gtk.Menu.destroy, menu)
 
         name.grab_focus()
         self.get_child().show_all()
@@ -149,7 +156,7 @@ class CBESEditor(_KeyValueEditor):
         self.cbes = cbes
         super(CBESEditor, self).__init__(title, validator)
         self.set_transient_for(qltk.get_top_parent(cbes))
-        self.connect_object('destroy', self.__finish, cbes)
+        connect_obj(self, 'destroy', self.__finish, cbes)
         self.value.set_text(cbes.get_child().get_text())
 
     def fill_values(self):
@@ -184,7 +191,7 @@ class StandaloneEditor(_KeyValueEditor):
         """Returns a list of tuples representing k,v pairs of the given file"""
         ret = []
         if os.path.exists(filename):
-            fileobj = file(filename, "rU")
+            fileobj = open(filename, "rU")
             lines = list(fileobj.readlines())
             for i in range(len(lines) / 2):
                 ret.append((lines[i * 2 + 1].strip(), lines[i * 2].strip()))
@@ -194,19 +201,18 @@ class StandaloneEditor(_KeyValueEditor):
         self.filename = filename
         self.initial = initial or []
         super(StandaloneEditor, self).__init__(title, validator)
-        self.connect_object('destroy', self.write, True)
+        connect_obj(self, 'destroy', self.write, True)
 
     def fill_values(self):
         filename = self.filename + ".saved"
         if os.path.exists(filename):
-            fileobj = file(filename, "rU")
+            fileobj = open(filename, "rU")
             lines = list(fileobj.readlines())
             lines.reverse()
             while len(lines) > 1:
                 self.model.prepend(
                     row=[lines.pop(1).strip(), lines.pop(0).strip()])
         if not len(self.model) and self.initial:
-            #print_d("None found - using defaults.", context=self)
             for (k, v) in self.initial:
                 self.model.append(row=[v.strip(), k.strip()])
 
@@ -218,15 +224,24 @@ class StandaloneEditor(_KeyValueEditor):
                 if not os.path.isdir(os.path.dirname(self.filename)):
                     os.makedirs(os.path.dirname(self.filename))
 
-            saved = file(self.filename + ".saved", "w")
-            for row in self.model:
-                saved.write(row[0] + "\n")
-                saved.write(row[1] + "\n")
-            saved.close()
+            with open(self.filename + ".saved", "w") as saved:
+                for row in self.model:
+                    saved.write(row[0] + "\n")
+                    saved.write(row[1] + "\n")
         except EnvironmentError:
             pass
 
-ICONS = {Gtk.STOCK_EDIT: CBESEditor}
+
+def clone_css_classes(src, dest):
+    """Makes dest have the same css classes as src"""
+
+    src_ctx = src.get_style_context()
+    dest_ctx = dest.get_style_context()
+
+    for class_ in dest_ctx.list_classes():
+        dest_ctx.remove_class(class_)
+    for class_ in src_ctx.list_classes():
+        dest_ctx.add_class(class_)
 
 
 class ComboBoxEntrySave(Gtk.ComboBox):
@@ -244,7 +259,7 @@ class ComboBoxEntrySave(Gtk.ComboBox):
 
     def __init__(self, filename=None, initial=[], count=5, id=None,
                  validator=None, title=_("Saved Values"),
-                 edit_title=_("Edit saved values...")):
+                 edit_title=_(u"Edit saved values…")):
         self.count = count
         self.filename = filename
         id = filename or id
@@ -260,7 +275,7 @@ class ComboBoxEntrySave(Gtk.ComboBox):
 
         render = Gtk.CellRendererPixbuf()
         self.pack_start(render, False)
-        self.add_attribute(render, 'stock-id', 2)
+        self.add_attribute(render, 'icon-name', 2)
 
         render = Gtk.CellRendererText()
         self.pack_start(render, True)
@@ -271,11 +286,14 @@ class ComboBoxEntrySave(Gtk.ComboBox):
         if not len(model):
             self.__fill(filename, initial, edit_title)
 
-        self.remove(self.get_child())
-        self.add(entry.ValidatingEntry(validator))
+        old_entry = self.get_child()
+        new_entry = entry.ValidatingEntry(validator)
+        clone_css_classes(old_entry, new_entry)
+        old_entry.destroy()
+        self.add(new_entry)
 
-        self.connect_object('destroy', self.set_model, None)
-        self.connect_object('changed', self.__changed, model,
+        connect_obj(self, 'destroy', self.set_model, None)
+        connect_obj(self, 'changed', self.__changed, model,
             validator, title)
 
     def enable_clear_button(self):
@@ -284,10 +302,9 @@ class ComboBoxEntrySave(Gtk.ComboBox):
     def __changed(self, model, validator, title):
         iter = self.get_active_iter()
         if iter:
-            if model[iter][2] in ICONS:
+            if model[iter][2]:
                 self.get_child().set_text(self.__last)
-                Kind = ICONS[model[iter][2]]
-                win = Kind(self, title, validator)
+                win = CBESEditor(self, title, validator)
                 win.show()
                 self.set_active(-1)
             else:
@@ -304,24 +321,25 @@ class ComboBoxEntrySave(Gtk.ComboBox):
 
     def __fill(self, filename, initial, edit_title):
         model = self.get_model()
-        model.append(row=["", edit_title, Gtk.STOCK_EDIT])
+        model.append(row=["", edit_title, Icons.DOCUMENT_PROPERTIES])
         model.append(row=[None, None, None])
 
         if filename is None:
             return
 
         if os.path.exists(filename + ".saved"):
-            fileobj = file(filename + ".saved", "rU")
-            lines = list(fileobj.readlines())
+            with open(filename + ".saved", "rU") as fileobj:
+                lines = list(fileobj.readlines())
             lines.reverse()
             while len(lines) > 1:
                 model.prepend(
                     row=[lines.pop(1).strip(), lines.pop(0).strip(), None])
 
         if os.path.exists(filename):
-            for line in file(filename, "rU").readlines():
-                line = line.strip()
-                model.append(row=[line, line, None])
+            with open(filename, "rU") as fileobj:
+                for line in fileobj.readlines():
+                    line = line.strip()
+                    model.append(row=[line, line, None])
 
         for c in initial:
             model.append(row=[c, c, None])
@@ -352,18 +370,16 @@ class ComboBoxEntrySave(Gtk.ComboBox):
                 if not os.path.isdir(os.path.dirname(filename)):
                     os.makedirs(os.path.dirname(filename))
 
-            saved = file(filename + ".saved", "w")
-            memory = file(filename, "w")
-            target = saved
-            for row in self.get_model():
-                if row[0] is None:
-                    target = memory
-                elif row[2] is None:
-                    target.write(row[0] + "\n")
-                    if target is saved:
-                        target.write(row[1] + "\n")
-            saved.close()
-            memory.close()
+            with open(filename + ".saved", "w") as saved:
+                with open(filename, "w") as memory:
+                    target = saved
+                    for row in self.get_model():
+                        if row[0] is None:
+                            target = memory
+                        elif row[2] is None:
+                            target.write(row[0] + "\n")
+                            if target is saved:
+                                target.write(row[1] + "\n")
         except EnvironmentError:
             pass
 
