@@ -16,6 +16,7 @@ from quodlibet import util
 
 from quodlibet.util import massagers
 
+from quodlibet.formats import AudioFileError
 from quodlibet.qltk.completion import LibraryValueCompletion
 from quodlibet.qltk.tagscombobox import TagsComboBox, TagsComboBoxEntry
 from quodlibet.qltk.views import RCMHintedTreeView, TreeViewColumn
@@ -28,7 +29,7 @@ from quodlibet.qltk._editutils import EditingPluginHandler, OverwriteWarning
 from quodlibet.qltk._editutils import WriteFailedError
 from quodlibet.qltk import Icons
 from quodlibet.plugins import PluginManager
-from quodlibet.util import connect_obj
+from quodlibet.util import connect_obj, gdecode
 from quodlibet.util.tags import USER_TAGS, MACHINE_TAGS, sortkey as tagsortkey
 from quodlibet.util.string.splitters import (split_value, split_title,
     split_people, split_album)
@@ -350,23 +351,19 @@ class AddTagDialog(Dialog):
             return self.__tag.tag
 
     def get_value(self):
-        return self.__val.get_text().decode("utf-8")
+        return gdecode(self.__val.get_text())
 
     def __validate(self, editable, add, invalid, box):
         tag = self.get_tag()
         value = self.get_value()
-        fmt = massagers.tags.get(tag)
-        if fmt:
-            valid = fmt.is_valid(value)
-        else:
-            valid = True
+        valid = massagers.is_valid(tag, value)
         add.set_sensitive(valid)
         if valid:
             invalid.hide()
             box.set_tooltip_text("")
         else:
             invalid.show()
-            box.set_tooltip_text(fmt.error)
+            box.set_tooltip_text(massagers.error_message(tag, value))
 
     def run(self):
         self.show()
@@ -414,23 +411,27 @@ class EditTags(Gtk.VBox):
         self._view = view
         selection = view.get_selection()
         render = Gtk.CellRendererPixbuf()
-        column = TreeViewColumn(_("Write"), render)
+        column = TreeViewColumn()
+        column.pack_start(render, True)
+        column.set_fixed_width(24)
+        column.set_expand(False)
 
         def cdf_write(col, rend, model, iter_, *args):
             entry = model.get_value(iter_)
+            rend.set_property('sensitive', entry.edited or entry.deleted)
             if entry.canedit or entry.deleted:
-                rend.set_property('sensitive', entry.edited or entry.deleted)
                 if entry.deleted:
                     rend.set_property('icon-name', Icons.EDIT_DELETE)
                 else:
                     rend.set_property('icon-name', Icons.EDIT)
             else:
-                rend.set_property('icon-name', Icons.DIALOG_PASSWORD)
+                rend.set_property('icon-name', Icons.CHANGES_PREVENT)
         column.set_cell_data_func(render, cdf_write)
         view.append_column(column)
 
         render = Gtk.CellRendererText()
-        column = TreeViewColumn(_('Tag'), render)
+        column = TreeViewColumn(title=_('Tag'))
+        column.pack_start(render, True)
 
         def cell_data_tag(column, cell, model, iter_, data):
             entry = model.get_value(iter_)
@@ -452,7 +453,8 @@ class EditTags(Gtk.VBox):
         render.connect('edited', self.__edit_tag, model)
         render.connect(
             'editing-started', self.__value_editing_started, model, library)
-        column = TreeViewColumn(_('Value'), render)
+        column = TreeViewColumn(title=_('Value'))
+        column.pack_start(render, True)
 
         def cell_data_value(column, cell, model, iter_, data):
             entry = model.get_value(iter_)
@@ -560,7 +562,8 @@ class EditTags(Gtk.VBox):
         for b in buttons:
             b.set_sensitive(True)
 
-    def __paste(self, clip, text, (rend, path)):
+    def __paste(self, clip, text, args):
+        rend, path = args
         if text:
             rend.emit('edited', path, text.strip())
 
@@ -681,9 +684,7 @@ class EditTags(Gtk.VBox):
             tag = add.get_tag()
             value = add.get_value()
             assert isinstance(value, unicode)
-            if tag in massagers.tags:
-                value = massagers.tags[tag].validate(value)
-                value = unicode(value)
+            value = massagers.validate(tag, value)
             assert isinstance(value, unicode)
             if not self.__songinfo.can_change(tag):
                 title = _("Invalid tag")
@@ -799,7 +800,7 @@ class EditTags(Gtk.VBox):
             if changed:
                 try:
                     song.write()
-                except:
+                except AudioFileError:
                     util.print_exc()
                     WriteFailedError(self, song).run()
                     library.reload(song, changed=was_changed)
@@ -823,15 +824,14 @@ class EditTags(Gtk.VBox):
         entry = model[path][0]
         error_dialog = None
 
-        if entry.tag in massagers.tags:
-            fmt = massagers.tags[entry.tag]
-            if not fmt.is_valid(new_value):
-                error_dialog = qltk.WarningMessage(
-                    self, _("Invalid value"),
-                    _("Invalid value: <b>%(value)s</b>\n\n%(error)s") % {
-                    "value": new_value, "error": fmt.error})
-            else:
-                new_value = fmt.validate(new_value)
+        if not massagers.is_valid(entry.tag, new_value):
+            error_dialog = qltk.WarningMessage(
+                self, _("Invalid value"),
+                _("Invalid value: <b>%(value)s</b>\n\n%(error)s") % {
+                "value": new_value,
+                "error": massagers.error_message(entry.tag, new_value)})
+        else:
+            new_value = massagers.validate(entry.tag, new_value)
 
         comment = entry.value
         changed = comment.text != new_value
@@ -864,15 +864,14 @@ class EditTags(Gtk.VBox):
             # validate one value and never write it back..
 
             text = entry.value.text
-            if new_tag in massagers.tags:
-                fmt = massagers.tags[new_tag]
-                if not fmt.is_valid(text):
-                    qltk.WarningMessage(
-                        self, _("Invalid value"),
-                        _("Invalid value: <b>%(value)s</b>\n\n%(error)s") % {
-                          "value": text, "error": fmt.error}).run()
-                    return
-                text = fmt.validate(text)
+            if not massagers.is_valid(new_tag, text):
+                qltk.WarningMessage(
+                    self, _("Invalid value"),
+                    _("Invalid value: <b>%(value)s</b>\n\n%(error)s") % {
+                      "value": text,
+                      "error": massagers.error_message(new_tag, text)}).run()
+                return
+            text = massagers.validate(new_tag, text)
 
             if entry.origvalue is None:
                 # The tag hasn't been saved yet, so we can just update
@@ -903,19 +902,7 @@ class EditTags(Gtk.VBox):
         except TypeError:
             return Gdk.EVENT_PROPAGATE
 
-        if event.button == Gdk.BUTTON_PRIMARY and col is view.get_columns()[0]:
-            model = view.get_model()
-            row = model[path]
-            entry = row[0]
-            # In case we have a (partially) shared value, write it
-            # to all songs. For unshared/incomplete do nothing
-            if entry.value.shared:
-                entry.edited = not entry.edited
-                if entry.edited:
-                    entry.value.complete = True
-            model.row_changed(row.path, row.iter)
-            return Gdk.EVENT_STOP
-        elif event.button == Gdk.BUTTON_MIDDLE and \
+        if event.button == Gdk.BUTTON_MIDDLE and \
                 col == view.get_columns()[2]:
             display = Gdk.DisplayManager.get().get_default_display()
             selection = Gdk.SELECTION_PRIMARY
