@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2009 Joe Wreschnig, Michael Urman, Iñigo Serna,
 #                     Steven Robertson
-#           2011-2015 Nick Boultbee
+#           2011-2016 Nick Boultbee
 #           2013      Christoph Reiter
 #           2014      Jan Path
 #
@@ -19,7 +19,8 @@ from quodlibet.config import RATINGS
 
 from quodlibet.qltk.ccb import ConfigCheckButton as CCB
 from quodlibet.qltk.data_editors import TagListEditor
-from quodlibet.qltk.entry import ValidatingEntry, UndoEntry, QueryValidator
+from quodlibet.qltk.entry import ValidatingEntry, UndoEntry
+from quodlibet.query._query import Query
 from quodlibet.qltk.scanbox import ScanBox
 from quodlibet.qltk.maskedbox import MaskedBox
 from quodlibet.qltk.songlist import SongList, get_columns
@@ -57,95 +58,95 @@ class PreferencesWindow(UniqueWindow):
             ("~#filesize", util.tag("~#filesize"))]
 
         def __init__(self):
+            def create_behaviour_frame():
+                vbox = Gtk.VBox(spacing=6)
+                c = CCB(_("_Jump to playing song automatically"),
+                        'settings', 'jump', populate=True,
+                        tooltip=_("When the playing song changes, "
+                                  "scroll to it in the song list"))
+                vbox.pack_start(c, False, True, 0)
+                frame = qltk.Frame(_("Behavior"), child=vbox)
+                return frame
+
+            def create_visible_columns_frame():
+                buttons = {}
+                vbox = Gtk.VBox(spacing=12)
+                table = Gtk.Table.new(3, 3, True)
+                for i, (k, t) in enumerate(self.PREDEFINED_TAGS):
+                    x, y = i % 3, i / 3
+                    buttons[k] = Gtk.CheckButton(label=t, use_underline=True)
+                    table.attach(buttons[k], x, x + 1, y, y + 1)
+                vbox.pack_start(table, False, True, 0)
+                # Other columns
+                hbox = Gtk.HBox(spacing=6)
+                l = Gtk.Label(label=_("_Others:"), use_underline=True)
+                hbox.pack_start(l, False, True, 0)
+                self.others = others = UndoEntry()
+                others.set_sensitive(False)
+                # Stock edit doesn't have ellipsis chars.
+                edit_button = Gtk.Button(
+                    label=_(u"_Edit…"), use_underline=True)
+                edit_button.connect("clicked", self.__config_cols, buttons)
+                edit_button.set_tooltip_text(
+                    _("Add or remove additional column "
+                      "headers"))
+                l.set_mnemonic_widget(edit_button)
+                l.set_use_underline(True)
+                hbox.pack_start(others, True, True, 0)
+                vbox.pack_start(hbox, False, True, 0)
+                b = Gtk.HButtonBox()
+                b.set_layout(Gtk.ButtonBoxStyle.END)
+                b.pack_start(edit_button, True, True, 0)
+                vbox.pack_start(b, True, True, 0)
+                return qltk.Frame(_("Visible Columns"), child=vbox), buttons
+
+            def create_columns_prefs_frame():
+                tiv = Gtk.CheckButton(label=_("Title includes _version"),
+                                      use_underline=True)
+                aio = Gtk.CheckButton(label=_("Artist includes all _people"),
+                                      use_underline=True)
+                aip = Gtk.CheckButton(label=_("Album includes _disc subtitle"),
+                                      use_underline=True)
+                fip = Gtk.CheckButton(label=_("Filename includes _folder"),
+                                      use_underline=True)
+                self._toggle_data = [
+                    (tiv, "title", "~title~version"),
+                    (aip, "album", "~album~discsubtitle"),
+                    (fip, "~basename", "~filename"),
+                    (aio, "artist", "~people")
+                ]
+                t = Gtk.Table.new(2, 2, True)
+                t.attach(tiv, 0, 1, 0, 1)
+                t.attach(aip, 0, 1, 1, 2)
+                t.attach(aio, 1, 2, 0, 1)
+                t.attach(fip, 1, 2, 1, 2)
+                return qltk.Frame(_("Column Preferences"), child=t)
+
+            def create_apply_button():
+                vbox = Gtk.VBox(spacing=12)
+                apply = Button(_("_Apply"))
+                apply.set_tooltip_text(
+                    _("Apply current configuration to song list, "
+                      "adding new columns to the end"))
+                apply.connect('clicked', self.__apply, buttons)
+                # Apply on destroy, else config gets mangled
+                self.connect('destroy', self.__apply, buttons)
+                b = Gtk.HButtonBox()
+                b.set_layout(Gtk.ButtonBoxStyle.END)
+                b.pack_start(apply, True, True, 0)
+                vbox.pack_start(b, True, True, 0)
+                return vbox
+
             super(PreferencesWindow.SongList, self).__init__(spacing=12)
             self.set_border_width(12)
             self.title = _("Song List")
-
-            # Behaviour
-            vbox = Gtk.VBox(spacing=6)
-            c = CCB(_("_Jump to playing song automatically"),
-                    'settings', 'jump', populate=True,
-                    tooltip=_("When the playing song changes, "
-                              "scroll to it in the song list"))
-            vbox.pack_start(c, False, True, 0)
-            frame = qltk.Frame(_("Behavior"), child=vbox)
-            self.pack_start(frame, False, True, 0)
-
-            # Columns
-            vbox = Gtk.VBox(spacing=12)
-            buttons = {}
-            table = Gtk.Table.new(3, 3, True)
-
-            for i, (k, t) in enumerate(self.PREDEFINED_TAGS):
-                x, y = i % 3, i / 3
-                buttons[k] = Gtk.CheckButton(label=t, use_underline=True)
-                table.attach(buttons[k], x, x + 1, y, y + 1)
-            vbox.pack_start(table, False, True, 0)
-
-            # Other columns
-            hbox = Gtk.HBox(spacing=6)
-            l = Gtk.Label(label=_("_Others:"), use_underline=True)
-            hbox.pack_start(l, False, True, 0)
-            self.others = others = UndoEntry()
-            others.set_sensitive(False)
-            # Stock edit doesn't have ellipsis chars.
-            edit_button = Gtk.Button(
-                label=_(u"_Edit…"), use_underline=True)
-            edit_button.connect("clicked", self.__config_cols, buttons)
-            edit_button.set_tooltip_text(_("Add or remove additional column "
-                                           "headers"))
-            l.set_mnemonic_widget(edit_button)
-            l.set_use_underline(True)
-            hbox.pack_start(others, True, True, 0)
-            vbox.pack_start(hbox, False, True, 0)
-            b = Gtk.HButtonBox()
-            b.set_layout(Gtk.ButtonBoxStyle.END)
-            b.pack_start(edit_button, True, True, 0)
-            vbox.pack_start(b, True, True, 0)
-
-            frame = qltk.Frame(_("Visible Columns"), child=vbox)
-            self.pack_start(frame, False, True, 0)
-
-            # Column preferences
-            tiv = Gtk.CheckButton(label=_("Title includes _version"),
-                                  use_underline=True)
-            aio = Gtk.CheckButton(label=_("Artist includes all _people"),
-                                  use_underline=True)
-            aip = Gtk.CheckButton(label=_("Album includes _disc subtitle"),
-                                  use_underline=True)
-            fip = Gtk.CheckButton(label=_("Filename includes _folder"),
-                                  use_underline=True)
-            self._toggle_data = [
-                (tiv, "title", "~title~version"),
-                (aip, "album", "~album~discsubtitle"),
-                (fip, "~basename", "~filename"),
-                (aio, "artist", "~people")
-            ]
-
+            self.pack_start(create_behaviour_frame(), False, True, 0)
+            columns_frame, buttons = create_visible_columns_frame()
+            self.pack_start(columns_frame, False, True, 0)
+            self.pack_start(create_columns_prefs_frame(), False, True, 0)
+            self.pack_start(create_apply_button(), True, True, 0)
             self.__update(buttons, self._toggle_data, get_columns())
 
-            t = Gtk.Table.new(2, 2, True)
-            t.attach(tiv, 0, 1, 0, 1)
-            t.attach(aip, 0, 1, 1, 2)
-            t.attach(aio, 1, 2, 0, 1)
-            t.attach(fip, 1, 2, 1, 2)
-            frame = qltk.Frame(_("Column Preferences"), child=t)
-            self.pack_start(frame, False, True, 0)
-
-            # Apply button
-            vbox = Gtk.VBox(spacing=12)
-            apply = Button(_("_Apply"))
-            apply.set_tooltip_text(_("Apply current configuration to song "
-                                     "list, adding new columns to the end"))
-            b = Gtk.HButtonBox()
-            b.set_layout(Gtk.ButtonBoxStyle.END)
-            b.pack_start(apply, True, True, 0)
-            vbox.pack_start(b, True, True, 0)
-            self.pack_start(vbox, True, True, 0)
-            apply.connect('clicked', self.__apply, buttons)
-            # Apply on destroy, else config gets mangled
-            self.connect('destroy', self.__apply, buttons)
-
             for child in self.get_children():
                 child.show_all()
 
@@ -236,7 +237,7 @@ class PreferencesWindow(UniqueWindow):
             hb = Gtk.HBox(spacing=6)
             l = Gtk.Label(label=_("_Global filter:"))
             l.set_use_underline(True)
-            e = ValidatingEntry(QueryValidator)
+            e = ValidatingEntry(Query.validator)
             e.set_text(config.get("browsers", "background"))
             e.connect('changed', self._entry, 'background', 'browsers')
             e.set_tooltip_text(_("Apply this query in addition to all others"))
@@ -267,14 +268,7 @@ class PreferencesWindow(UniqueWindow):
             f = qltk.Frame(_("Ratings"), child=vbox)
             self.pack_start(f, False, True, 0)
 
-            # Album Art
             vb = Gtk.VBox(spacing=6)
-            c = CCB(_("_Use rounded corners on thumbnails"),
-                    'albumart', 'round', populate=True,
-                    tooltip=_("Round the corners of album artwork thumbnail "
-                              "images."))
-            c.connect('toggled', self.__toggle_round_corners)
-            vb.pack_start(c, False, True, 0)
 
             # Filename choice algorithm config
             cb = CCB(_("Prefer _embedded art"),
@@ -310,9 +304,6 @@ class PreferencesWindow(UniqueWindow):
         def __changed_text(self, entry, name):
             config.set('albumart', name, entry.get_text())
 
-        def __toggle_round_corners(self, *args):
-            qltk.redraw_all_toplevels()
-
         def __toggled_force_filename(self, cb, fn_entry):
             fn_entry.set_sensitive(cb.get_active())
 
@@ -607,7 +598,7 @@ class PreferencesWindow(UniqueWindow):
             self.set_border_width(12)
             self.title = _("Library")
 
-            cb = CCB(_("_Refresh library on start"),
+            cb = CCB(_("Scan library _on start"),
                      "library", "refresh_on_start", populate=True)
             scan_dirs = ScanBox()
 
@@ -617,14 +608,14 @@ class PreferencesWindow(UniqueWindow):
             def refresh_cb(button):
                 scan_library(app.library, force=False)
 
-            refresh = qltk.Button(_("Re_fresh Library"), Icons.VIEW_REFRESH)
+            refresh = qltk.Button(_("_Scan Library"), Icons.VIEW_REFRESH)
             refresh.connect("clicked", refresh_cb)
             refresh.set_tooltip_text(_("Check for changes in your library"))
 
             def reload_cb(button):
                 scan_library(app.library, force=True)
 
-            reload_ = qltk.Button(_("Re_load Library"), Icons.VIEW_REFRESH)
+            reload_ = qltk.Button(_("Re_build Library"), Icons.VIEW_REFRESH)
             reload_.connect("clicked", reload_cb)
             reload_.set_tooltip_text(
                 _("Reload all songs in your library. "
