@@ -15,7 +15,7 @@ from quodlibet import util
 from quodlibet import qltk
 
 from quodlibet.util import connect_obj, connect_destroy
-from quodlibet.qltk import Icons
+from quodlibet.qltk import Icons, gtk_version, add_css
 from quodlibet.qltk.ccb import ConfigCheckButton
 from quodlibet.qltk.songlist import SongList, DND_QL, DND_URI_LIST
 from quodlibet.qltk.songsmenu import SongsMenu
@@ -57,16 +57,34 @@ class PlaybackStatusIcon(Gtk.Box):
         self._set("media-playback-pause")
 
 
+class ExpandBoxHack(Gtk.HBox):
+
+    def do_get_preferred_width(self):
+        # Workaround for https://bugzilla.gnome.org/show_bug.cgi?id=765602
+        # set_label_fill() no longer works since 3.20. Fake a natural size
+        # which is larger than the expander can be to force the parent to
+        # allocate to us the whole space.
+        min_, nat = Gtk.HBox.do_get_preferred_width(self)
+        if gtk_version > (3, 19):
+            # if we get too large gtk calcs will overflow..
+            nat = max(nat, 2 ** 16)
+        return (min_, nat)
+
+
 class QueueExpander(Gtk.Expander):
-    def __init__(self, menu, library, player):
+
+    def __init__(self, library, player):
         super(QueueExpander, self).__init__(spacing=3)
         sw = ScrolledWindow()
         sw.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         sw.set_shadow_type(Gtk.ShadowType.IN)
         self.queue = PlayQueue(library, player)
+        self.queue.props.expand = True
         sw.add(self.queue)
 
-        outer = Gtk.HBox(spacing=12)
+        add_css(self, ".ql-expanded title { margin-bottom: 5px; }")
+
+        outer = ExpandBoxHack(spacing=12)
 
         left = Gtk.HBox(spacing=12)
 
@@ -80,11 +98,10 @@ class QueueExpander(Gtk.Expander):
         left.pack_start(hb2, False, True, 0)
 
         b = SmallImageButton(
-            image=Gtk.Image.new_from_icon_name(Icons.EDIT_CLEAR,
-                                               Gtk.IconSize.MENU))
+            image=SymbolicIconImage(Icons.EDIT_CLEAR, Gtk.IconSize.MENU))
         b.set_tooltip_text(_("Remove all songs from the queue"))
         b.connect('clicked', self.__clear_queue)
-        b.hide()
+        b.set_no_show_all(True)
         b.set_relief(Gtk.ReliefStyle.NONE)
         left.pack_start(b, False, False, 0)
 
@@ -106,6 +123,7 @@ class QueueExpander(Gtk.Expander):
             _("_Random"), "memory", "shufflequeue")
         cb.connect('toggled', self.__queue_shuffle, self.queue.model)
         cb.set_active(config.getboolean("memory", "shufflequeue"))
+        cb.set_no_show_all(True)
         left.pack_start(cb, False, True, 0)
 
         self.set_label_widget(outer)
@@ -122,15 +140,12 @@ class QueueExpander(Gtk.Expander):
         self.connect('drag-motion', self.__motion)
         self.connect('drag-data-received', self.__drag_data_received)
 
-        self.show_all()
-
         self.queue.model.connect_after('row-inserted',
             util.DeferredSignal(self.__check_expand), count_label)
         self.queue.model.connect_after('row-deleted',
             util.DeferredSignal(self.__update_count), count_label)
-        cb.hide()
 
-        connect_obj(self, 'notify::visible', self.__visible, cb, menu, b)
+        connect_obj(self, 'notify::visible', self.__visible, cb, b)
         self.__update_count(self.model, None, count_label)
 
         connect_destroy(
@@ -151,6 +166,12 @@ class QueueExpander(Gtk.Expander):
                 label.map()
         self.connect("map", hack)
 
+        self.set_expanded(config.getboolean("memory", "queue_expanded"))
+        self.notify("expanded")
+
+        for child in self.get_children():
+            child.show_all()
+
     @property
     def model(self):
         return self.queue.model
@@ -189,8 +210,6 @@ class QueueExpander(Gtk.Expander):
         lab.set_text(text)
 
     def __check_expand(self, model, path, iter, lab):
-        if not self.get_property('visible'):
-            self.set_expanded(False)
         self.__update_count(model, path, lab)
         self.show()
 
@@ -204,16 +223,21 @@ class QueueExpander(Gtk.Expander):
             model.order = OrderShuffle(model)
 
     def __expand(self, cb, prop, clear):
-        cb.set_property('visible', self.get_expanded())
-        clear.set_property('visible', self.get_expanded())
+        expanded = self.get_expanded()
 
-    def __visible(self, cb, prop, menu, clear):
+        style_context = self.get_style_context()
+        if expanded:
+            style_context.add_class("ql-expanded")
+        else:
+            style_context.remove_class("ql-expanded")
+
+        cb.set_property('visible', expanded)
+        clear.set_property('visible', expanded)
+        config.set("memory", "queue_expanded", str(expanded))
+
+    def __visible(self, cb, prop, clear):
         value = self.get_property('visible')
         config.set("memory", "queue", str(value))
-        menu.set_active(value)
-        self.set_expanded(not self.model.is_empty())
-        cb.set_property('visible', self.get_expanded())
-        clear.set_property('visible', self.get_expanded())
 
 
 class QueueModel(PlaylistModel):
@@ -258,7 +282,8 @@ class PlayQueue(SongList):
 
     def __fill(self, library):
         try:
-            filenames = file(QUEUE, "rU").readlines()
+            with open(QUEUE, "rU") as f:
+                filenames = f.readlines()
         except EnvironmentError:
             pass
         else:
@@ -271,9 +296,8 @@ class PlayQueue(SongList):
 
     def __write(self, model):
         filenames = "\n".join([row[0]["~filename"] for row in model])
-        f = file(QUEUE, "w")
-        f.write(filenames)
-        f.close()
+        with open(QUEUE, "w") as f:
+            f.write(filenames)
 
     def __popup(self, library):
         songs = self.get_selected_songs()
