@@ -14,8 +14,8 @@ import cairo
 
 from quodlibet import config
 from quodlibet.qltk import get_top_parent, is_accel, is_wayland, gtk_version, \
-    menu_popup
-from quodlibet.qltk.image import pbosf_get_rect
+    menu_popup, get_primary_accel_mod
+from quodlibet.qltk.image import get_surface_extents
 
 
 class TreeViewHints(Gtk.Window):
@@ -37,7 +37,16 @@ class TreeViewHints(Gtk.Window):
         'override')
 
     def __init__(self):
+        try:
+            # gtk+ 3.20
+            TreeViewHints.set_css_name("tooltip")
+        except AttributeError:
+            pass
+
         super(TreeViewHints, self).__init__(type=Gtk.WindowType.POPUP)
+        # set the type hint so the wayland backend maps it as a subsurface
+        # which supports relative positioning
+        self.set_type_hint(Gdk.WindowTypeHint.TOOLTIP)
         self.__clabel = Gtk.Label()
         self.__clabel.show()
         self.__clabel.set_alignment(0, 0.5)
@@ -88,7 +97,7 @@ class TreeViewHints(Gtk.Window):
         # don't depend on padding set by theme, we need the text coordinates
         # to match in all cases
         self._style_provider = style_provider = Gtk.CssProvider()
-        style_provider.load_from_data("""
+        style_provider.load_from_data(b"""
             .ql-tooltip * {
                 border-width: 0px;
                 padding: 0px;
@@ -191,7 +200,7 @@ class TreeViewHints(Gtk.Window):
         # get the renderer at the mouse position and get the xpos/width
         renderers = col.get_cells()
         pos = sorted(zip(map(col.cell_get_position, renderers), renderers))
-        pos = filter(lambda ((x, w), r): x < cellx, pos)
+        pos = filter(lambda p: p[0][0] < cellx, pos)
         if not pos:
             self.__undisplay()
             return False
@@ -406,8 +415,7 @@ class TreeViewHints(Gtk.Window):
         if event.type == Gdk.EventType.BUTTON_PRESS:
             # hack: present is overridden to present all windows.
             # bypass to only select one
-            if not is_wayland():  # present duplicates windows in weston
-                Gtk.Window.present(get_top_parent(self.__view))
+            Gtk.Window.present(get_top_parent(self.__view))
 
         def translate_enter_leave_event(event):
             # enter/leave events have different x/y values as motion events
@@ -602,9 +610,51 @@ class DragScroll(object):
 
 class BaseView(Gtk.TreeView):
 
+    __gsignals__ = {
+        # like the tree selection changed signal but doesn't emit twice in case
+        # a row is activated
+        'selection-changed': (
+            GObject.SignalFlags.RUN_LAST, None, (object, )),
+    }
+
     def __init__(self, *args, **kwargs):
         super(BaseView, self).__init__(*args, **kwargs)
         self.connect("key-press-event", self.__key_pressed)
+        self._setup_selection_signal()
+
+    def _setup_selection_signal(self):
+        # Forwards selection changed events except in case row-activated
+        # just happened and the selection changed event is a result of the
+        # button release after the row-activated event.
+        # This makes the selection change only once in case of double clicking
+        # a row.
+
+        self._sel_ignore_next = False
+        self._sel_ignore_time = -1
+
+        def on_selection_changed(selection):
+            if self._sel_ignore_time != Gtk.get_current_event_time():
+                self.emit("selection-changed", selection)
+            self._sel_ignore_time = -1
+
+        id_ = self.get_selection().connect('changed', on_selection_changed)
+
+        def on_destroy(self):
+            self.get_selection().disconnect(id_)
+
+        self.connect('destroy', on_destroy)
+
+        def on_row_activated(*args):
+            self._sel_ignore_next = True
+
+        self.connect_after("row-activated", on_row_activated)
+
+        def on_button_release_event(self, event):
+            if self._sel_ignore_next:
+                self._sel_ignore_time = Gtk.get_current_event_time()
+            self._sel_ignore_next = False
+
+        self.connect("button-release-event", on_button_release_event)
 
     def __key_pressed(self, view, event):
         def get_first_selected():
@@ -681,6 +731,66 @@ class BaseView(Gtk.TreeView):
                     break
         return not first
 
+    def iter_select_by_func(self, func, scroll=True):
+        """Selects the next row after the current selection for which func
+        returns True, removing the selection of all other rows.
+
+        func gets passed Gtk.TreeModelRow and should return True if
+        the row should be selected.
+
+        If scroll=True then scroll to the selected row if the selection
+        changes.
+
+        Returns True if the selection was changed.
+        """
+
+        model = self.get_model()
+        if not model:
+            return False
+
+        if not model.get_iter_first():
+            # empty model
+            return False
+
+        selection = self.get_selection()
+        model, paths = selection.get_selected_rows()
+
+        # get the last iter we shouldn't be looking at
+        if not paths:
+            last_iter = model[-1].iter
+        else:
+            last_iter = model.get_iter(paths[-1])
+
+        # get the first iter we should be looking at
+        start_iter = model.iter_next(last_iter)
+        if start_iter is None:
+            start_iter = model.get_iter_first()
+
+        row_iter = Gtk.TreeModelRowIter(model, start_iter)
+
+        for row in row_iter:
+            if not func(row):
+                continue
+            self.set_cursor(row.path)
+            if scroll:
+                self.scroll_to_cell(row.path, use_align=True,
+                                    row_align=0.5)
+            return True
+
+        last_path = model.get_path(last_iter)
+        for row in model:
+            if row.path.compare(last_path) == 0:
+                return False
+            if not func(row):
+                continue
+            self.set_cursor(row.path)
+            if scroll:
+                self.scroll_to_cell(row.path, use_align=True,
+                                    row_align=0.5)
+            return True
+
+        return False
+
     def set_drag_dest(self, x, y, into_only=False):
         """Sets a drag destination for widget coords
 
@@ -788,7 +898,7 @@ class DragIconTreeView(BaseView):
         if not icons:
             return
 
-        sizes = [pbosf_get_rect(s) for s in icons]
+        sizes = [get_surface_extents(s) for s in icons]
         if None in sizes:
             return
         width = max([s[2] for s in sizes])
@@ -871,7 +981,7 @@ class MultiDragTreeView(BaseView):
         selection = self.get_selection()
         is_selected = selection.path_is_selected(path)
         mod_active = event.get_state() & (
-            Gdk.ModifierType.CONTROL_MASK | Gdk.ModifierType.SHIFT_MASK)
+            get_primary_accel_mod() | Gdk.ModifierType.SHIFT_MASK)
 
         if is_selected and not mod_active:
             self.__pending_event = [x, y]
@@ -1038,8 +1148,6 @@ class _TreeViewColumnLabel(Gtk.Label):
     """
 
     def do_draw(self, ctx):
-        # TODO: doesn't do anything in RTL mode
-
         alloc = self.get_allocation()
         # in case there are no parents use the same alloc which should
         # result in no custom drawing.
@@ -1049,17 +1157,18 @@ class _TreeViewColumnLabel(Gtk.Label):
         p2_alloc = p2.get_allocation()
         p3_alloc = p3.get_allocation()
 
-        available_width = p2_alloc.width
         # remove the space needed by the arrow and add the space
         # added by the padding so we only start drawing when we clip
         # the text directly
-        available_width += (p2_alloc.x - alloc.x) + (p2_alloc.x - p3_alloc.x)
+        available_width = p2_alloc.width - \
+            abs(p2_alloc.x - alloc.x) + (p2_alloc.x - p3_alloc.x)
 
         if alloc.width <= available_width:
             return Gtk.Label.do_draw(self, ctx)
 
         req_height = self.get_requisition().height
-        w, h = available_width, alloc.height
+        w, h = alloc.width, alloc.height
+        aw = available_width
 
         # possible when adding new columns.... create_similar will fail
         # in this case below, so just skip.
@@ -1075,12 +1184,18 @@ class _TreeViewColumnLabel(Gtk.Label):
 
         # create a gradient.
         # make the gradient width depend roughly on the font size
-        gradient_width = req_height * 0.8
-        gradient_x0 = w - min(float(gradient_width), w)
+        gradient_width = min(req_height * 0.8, aw)
 
-        pat = cairo.LinearGradient(gradient_x0, 0, w, 0)
-        pat.add_color_stop_rgba(0, 1, 1, 1, 1)
-        pat.add_color_stop_rgba(w, 0, 0, 0, 0)
+        if self.get_direction() == Gtk.TextDirection.RTL:
+            start = (w - aw)
+            end = start + gradient_width
+        else:
+            end = (aw - gradient_width)
+            start = end + gradient_width
+
+        pat = cairo.LinearGradient(start, 0, end, 0)
+        pat.add_color_stop_rgba(0, 0, 0, 0, 0)
+        pat.add_color_stop_rgba(gradient_width, 1, 1, 1, 1)
 
         # gradient surface
         grad_surface = surface.create_similar(cairo.CONTENT_COLOR_ALPHA, w, h)
@@ -1098,8 +1213,20 @@ class _TreeViewColumnLabel(Gtk.Label):
 
 
 class TreeViewColumn(Gtk.TreeViewColumn):
-    def __init__(self, title="", *args, **kwargs):
-        super(TreeViewColumn, self).__init__(None, *args, **kwargs)
+
+    __gsignals__ = {
+        # tree-view-changed(old_tree_view, new_tree_view)
+        # Triggers when the columns gets added/removed from a tree view.
+        # The passed values are either a TreeView or None
+        'tree-view-changed': (
+            GObject.SignalFlags.RUN_LAST, None, (object, object)),
+    }
+
+    def __init__(self, **kwargs):
+        title = kwargs.pop("title", u"")
+        # skip overrides which don't allow to set properties
+        GObject.Object.__init__(self, **kwargs)
+
         label = _TreeViewColumnLabel(label=title)
         label.set_padding(1, 1)
         label.show()
@@ -1107,17 +1234,25 @@ class TreeViewColumn(Gtk.TreeViewColumn):
 
         # the button gets created once the widget gets realized
         self._button = None
-        label.__realize = label.connect('realize', self.__realized)
         self._tooltip_text = None
+        label.__realize = label.connect('realize', self.__realized)
 
     def __realized(self, widget):
         widget.disconnect(widget.__realize)
         self._button = widget.get_ancestor(Gtk.Button)
         self.set_tooltip_text(self._tooltip_text)
 
+        def on_parent_set(button, old_parent):
+            new_parent = button.get_parent()
+            assert new_parent is None or isinstance(new_parent, Gtk.TreeView)
+            self.emit("tree-view-changed", old_parent, new_parent)
+
+        # parent already set, emit manually
+        on_parent_set(self._button, None)
+        self._button.connect("parent-set", on_parent_set)
+
     def set_tooltip_text(self, text):
         if self._button:
-            # gtk3.4: set_tooltip_text didn't allow None
             self._button.props.tooltip_text = text
         else:
             self._tooltip_text = text
@@ -1137,8 +1272,8 @@ class TreeViewColumnButton(TreeViewColumn):
         'popup-menu': (GObject.SignalFlags.RUN_LAST, bool, ()),
     }
 
-    def __init__(self, title="", *args, **kw):
-        super(TreeViewColumnButton, self).__init__(title, *args, **kw)
+    def __init__(self, **kwargs):
+        super(TreeViewColumnButton, self).__init__(**kwargs)
         label = self.get_widget()
         label.__realize = label.connect('realize', self.__connect_menu_event)
 
