@@ -9,6 +9,7 @@
 import os
 import contextlib
 import sys
+import shutil
 
 from gi.repository import Gtk, Gdk
 
@@ -248,6 +249,18 @@ def temp_filename(*args, **kwargs):
     os.remove(filename)
 
 
+def get_temp_copy(path):
+    """Returns a copy of the file with the same extension"""
+
+    from tests import mkstemp
+
+    ext = os.path.splitext(path)[-1]
+    fd, filename = mkstemp(suffix=ext)
+    os.close(fd)
+    shutil.copy(path, filename)
+    return filename
+
+
 class ListWithUnused(object):
     """ This class stores a set of elements and provides the interface to check
         if it contains an arbitrary element, and then to know if some of the
