@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 import os
 
 import quodlibet
+from quodlibet import util
 from quodlibet.util.modulescanner import ModuleScanner
 from quodlibet.plugins import list_plugins, Plugin, PluginImportException
 from quodlibet.compat import PY3, iteritems
 
-from tests import AbstractTestCase, init_fake_app, destroy_fake_app
+from tests import TestCase, init_fake_app, destroy_fake_app
 
 
 init_fake_app, destroy_fake_app
@@ -23,7 +28,7 @@ for entry in os.listdir(root):
         continue
     PLUGIN_DIRS.append(path)
 
-PLUGIN_DIRS.append(os.path.join(os.path.dirname(__file__), "test_plugins"))
+PLUGIN_DIRS.append(os.path.join(util.get_module_dir(), "test_plugins"))
 
 ms = ModuleScanner(PLUGIN_DIRS)
 
@@ -47,7 +52,8 @@ for name, module in iteritems(ms.modules):
         modules[plugin.PLUGIN_ID] = module.module
 
 
-class PluginTestCase(AbstractTestCase):
+class PluginTestCase(TestCase):
     """Base class for all plugin tests"""
+
     plugins = plugins
     modules = modules
