@@ -16,19 +16,16 @@ except ImportError:
 
 from quodlibet.compat import PY3
 
-from tests import TestCase, skipUnless
+from tests import TestCase
 
 
 class FakeStream(object):
     # skip these by default
-    BL = [
-        "unable to detect undefined names",
-        "may be undefined, or defined from star imports",
-        re.escape(".*' imported but unused"),
-    ]
+    BL = []
     if PY3:
         BL.append(
-            "undefined name '(unichr|unicode|long|basestring|xrange|cmp)'")
+            "undefined name "
+            "'(unichr|unicode|long|basestring|xrange|cmp|execfile|reload)'")
 
     def __init__(self, blacklist=None):
         self.lines = []
@@ -50,10 +47,12 @@ class FakeStream(object):
             raise Exception("\n" + "\n".join(self.lines))
 
 
-@skipUnless(pyflakes, "pyflakes not found")
 class TPyFlakes(TestCase):
 
     def __check_path(self, path):
+        if not pyflakes:
+            raise Exception("pyflakes missing; please install")
+
         old_stdout = sys.stdout
         stream = FakeStream()
         try:
