@@ -9,6 +9,7 @@ from tests import TestCase
 
 import quodlibet
 from quodlibet import config
+from quodlibet.const import Version
 from quodlibet.util.path import is_fsnative
 
 
@@ -32,3 +33,21 @@ class TQuodlibet(TestCase):
         self.assertTrue(is_fsnative(quodlibet.get_base_dir()))
         self.assertTrue(is_fsnative(quodlibet.get_image_dir()))
         self.assertTrue(is_fsnative(quodlibet.get_user_dir()))
+
+    def test_get_build_description(self):
+        quodlibet.get_build_description()
+
+    def test_get_build_version(self):
+        ver = quodlibet.get_build_version()
+        self.assertTrue(isinstance(ver, tuple))
+
+
+class TVersion(TestCase):
+
+    def test_message(self):
+        v = Version("foo", 1, 2, message="bla")
+        self.assertRaises(ImportError, v.check, (1, 1))
+        try:
+            v.check((1, 1))
+        except ImportError as e:
+            self.assertTrue("bla" in str(e))
