@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 import os
 from quodlibet.config import RatingsPrefs
 from tests import TestCase, mkstemp
-from .helper import capture_output
 
 from quodlibet import config
 
@@ -21,9 +24,7 @@ class Tconfig(TestCase):
         with open(filename, "wb") as f:
             f.write(garbage)
 
-        with capture_output() as (stdout, stderr):
-            config.init(filename)
-        self.assertTrue(stderr.getvalue())
+        config.init(filename)
         self.assertTrue(config.options("player"))
 
         invalid_filename = filename + ".not-valid"
