@@ -6,33 +6,27 @@
 # published by the Free Software Foundation
 
 import os
-import shutil
 
-import mutagen
 from mutagen import asf
 
-from tests import TestCase, DATA_DIR, mkstemp
+from tests import TestCase, DATA_DIR
 from quodlibet.formats.wma import WMAFile, unpack_image, pack_image
 from quodlibet.formats._image import APICType, EmbeddedImage
 from quodlibet.compat import cBytesIO
 
+from .helper import get_temp_copy
+
 
 class TWMAFile(TestCase):
 
     def setUp(self):
-        fd, self.f = mkstemp(".wma")
-        os.close(fd)
-        shutil.copy(os.path.join(DATA_DIR, 'test.wma'), self.f)
+        self.f = get_temp_copy(os.path.join(DATA_DIR, 'test.wma'))
         self.song = WMAFile(self.f)
 
-        fd, self.f2 = mkstemp(".wma")
-        os.close(fd)
-        shutil.copy(os.path.join(DATA_DIR, 'test-2.wma'), self.f2)
+        self.f2 = get_temp_copy(os.path.join(DATA_DIR, 'test-2.wma'))
         self.song2 = WMAFile(self.f2)
 
-        fd, self.f3 = mkstemp(".asf")
-        os.close(fd)
-        shutil.copy(os.path.join(DATA_DIR, 'test.asf'), self.f3)
+        self.f3 = get_temp_copy(os.path.join(DATA_DIR, 'test.asf'))
         self.song3 = WMAFile(self.f3)
 
     def tearDown(self):
@@ -79,8 +73,6 @@ class TWMAFile(TestCase):
         self.assertEqual(self.song3("~format"), "ASF")
 
     def test_codec(self):
-        if mutagen.version < (1, 31):
-            return
         self.assertEqual(self.song("~codec"),
                          u"Windows Media Audio 9 Standard")
         self.assertEqual(self.song2("~codec"),
@@ -89,8 +81,6 @@ class TWMAFile(TestCase):
                          u"Intel G.723")
 
     def test_encoding(self):
-        if mutagen.version < (1, 31):
-            return
         self.assertEqual(
             self.song("~encoding"),
             u"Windows Media Audio 9.1\n64 kbps, 48 kHz, stereo 2-pass CBR")
@@ -101,6 +91,17 @@ class TWMAFile(TestCase):
         self.assertEqual(self.song3("~encoding"),
                          u"Microsoft G.723.1\n8 kHz Mono, 5333 Bit/s")
 
+    def test_mb_release_track_id(self):
+        tag = asf.ASF(self.f)
+        tag["MusicBrainz/Release Track Id"] = [u"foo"]
+        tag.save()
+        song = WMAFile(self.f)
+        self.assertEqual(song("musicbrainz_releasetrackid"), u"foo")
+        song["musicbrainz_releasetrackid"] = u"bla"
+        song.write()
+        tag = asf.ASF(self.f)
+        self.assertEqual(tag["MusicBrainz/Release Track Id"], [u"bla"])
+
     def test_invalid(self):
         path = os.path.join(DATA_DIR, 'empty.xm')
         self.assertTrue(os.path.exists(path))
@@ -121,11 +122,11 @@ class TWMAFile(TestCase):
         image = self.song2.get_primary_image()
         self.assertTrue(image)
         self.assertEqual(image.mime_type, "image/jpeg")
-        self.assertTrue(image.file.read())
+        self.assertTrue(image.read())
 
     def test_get_image_invalid_data(self):
         tag = asf.ASF(self.f)
-        tag["WM/Picture"] = [asf.ASFValue("nope", asf.BYTEARRAY)]
+        tag["WM/Picture"] = [asf.ASFValue(b"nope", asf.BYTEARRAY)]
         tag.save()
 
         self.assertFalse(self.song.has_images)
@@ -136,26 +137,26 @@ class TWMAFile(TestCase):
         self.assertFalse(image)
 
     def test_unpack_image_min(self):
-        data = "\x03" + "\x00" * 4 + "\x00" * 4
+        data = b"\x03" + b"\x00" * 4 + b"\x00" * 4
         mime, desc, data, type_ = unpack_image(data)
         self.assertEqual(mime, u"")
         self.assertEqual(desc, u"")
-        self.assertEqual(data, "")
+        self.assertEqual(data, b"")
         self.assertEqual(type_, 3)
 
     def test_unpack_image_invalid(self):
-        self.assertRaises(ValueError, unpack_image, "")
-        self.assertRaises(ValueError, unpack_image, "\x00" * 6)
-        self.assertRaises(ValueError, unpack_image, "\x00" * 8)
-        self.assertRaises(ValueError, unpack_image, "\x00" * 100)
+        self.assertRaises(ValueError, unpack_image, b"")
+        self.assertRaises(ValueError, unpack_image, b"\x00" * 6)
+        self.assertRaises(ValueError, unpack_image, b"\x00" * 8)
+        self.assertRaises(ValueError, unpack_image, b"\x00" * 100)
 
     def test_pack_image(self):
         d = pack_image(
-            u"image/jpeg", u"Description", "foo", APICType.COVER_FRONT)
+            u"image/jpeg", u"Description", b"foo", APICType.COVER_FRONT)
         mime, desc, data, type_ = unpack_image(d)
         self.assertEqual(mime, u"image/jpeg")
         self.assertEqual(desc, u"Description")
-        self.assertEqual(data, "foo")
+        self.assertEqual(data, b"foo")
         self.assertEqual(type_, APICType.COVER_FRONT)
 
     def test_clear_images(self):
@@ -180,7 +181,7 @@ class TWMAFile(TestCase):
 
         image = self.song.get_primary_image()
         self.assertEqual(image.mime_type, "image/jpeg")
-        self.assertEqual(image.file.read(), "foo")
+        self.assertEqual(image.read(), b"foo")
 
     def test_can_change_images(self):
         self.assertTrue(self.song.can_change_images)
