@@ -1,21 +1,26 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 from quodlibet.config import RATINGS
 from tests import DATA_DIR, skipUnless, mkstemp, TestCase
 
 import os
 import sys
-import shutil
 import base64
 
 from quodlibet import config, const, formats
 from quodlibet.formats.xiph import OggFile, FLACFile, OggOpusFile, OggOpus
 from quodlibet.formats._image import EmbeddedImage, APICType
-from quodlibet.compat import long, cBytesIO
+from quodlibet.compat import long, cBytesIO, iteritems
 
 from mutagen.flac import FLAC, Picture
 from mutagen.id3 import ID3, TIT2, ID3NoHeaderError
 from mutagen.oggvorbis import OggVorbis
 
+from .helper import get_temp_copy
+
 
 def _get_jpeg(size=5):
     from gi.repository import GdkPixbuf
@@ -23,7 +28,7 @@ def _get_jpeg(size=5):
         GdkPixbuf.Colorspace.RGB, False, 8, size, size)
     fd, fn = mkstemp()
     pb.savev(fn, "jpeg", [], [])
-    with os.fdopen(fd) as h:
+    with os.fdopen(fd, "rb") as h:
         data = h.read()
     os.unlink(fn)
     return data
@@ -153,9 +158,7 @@ class TTotalTagsBase(TestCase):
 
     def setUp(self):
         config.init()
-        h, self.filename = mkstemp(".ogg")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.ogg'))
 
     def tearDown(self):
         os.unlink(self.filename)
@@ -166,11 +169,11 @@ class TTotalTagsMixin(object):
 
     def __load_tags(self, tags, expected):
         m = OggVorbis(self.filename)
-        for key, value in tags.iteritems():
+        for key, value in iteritems(tags):
             m.tags[key] = value
         m.save()
         song = OggFile(self.filename)
-        for key, value in expected.iteritems():
+        for key, value in iteritems(expected):
             self.failUnlessEqual(song(key), value)
         if self.MAIN not in expected:
             self.failIf(self.MAIN in song)
@@ -217,12 +220,12 @@ class TTotalTagsMixin(object):
     def __save_tags(self, tags, expected):
         #return
         song = OggFile(self.filename)
-        for key, value in tags.iteritems():
+        for key, value in iteritems(tags):
             song[key] = value
         song.write()
         m = OggVorbis(self.filename)
         # test if all values ended up where we wanted
-        for key, value in expected.iteritems():
+        for key, value in iteritems(expected):
             self.failUnless(key in m.tags)
             self.failUnlessEqual(m.tags[key], [value])
 
@@ -282,9 +285,8 @@ class TDiscTotal(TTotalTagsBase, TTotalTagsMixin):
 class TFLACFile(TVCFile, TVCFileMixin):
     def setUp(self):
         TVCFile.setUp(self)
-        h, self.filename = mkstemp(".flac")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
+
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.flac'))
         self.song = FLACFile(self.filename)
 
     def test_format_codec(self):
@@ -342,8 +344,8 @@ class TVCCoverMixin(object):
         # coverart + coverartmime
         data = _get_jpeg()
         song = self.MutagenType(self.filename)
-        song["coverart"] = base64.b64encode(data)
-        song["coverartmime"] = "image/jpeg"
+        song["coverart"] = base64.b64encode(data).decode("ascii")
+        song["coverartmime"] = u"image/jpeg"
         song.save()
 
         song = self.QLType(self.filename)
@@ -354,7 +356,7 @@ class TVCCoverMixin(object):
         pic = Picture()
         pic.data = _get_jpeg()
         pic.type = APICType.COVER_FRONT
-        b64pic_cover = base64.b64encode(pic.write())
+        b64pic_cover = base64.b64encode(pic.write()).decode("ascii")
 
         song = self.MutagenType(self.filename)
         song["metadata_block_picture"] = [b64pic_cover]
@@ -367,7 +369,7 @@ class TVCCoverMixin(object):
     def test_handle_old_coverart(self):
         data = _get_jpeg()
         song = self.MutagenType(self.filename)
-        song["coverart"] = base64.b64encode(data)
+        song["coverart"] = base64.b64encode(data).decode("ascii")
         song["coverartmime"] = "image/jpeg"
         song.save()
 
@@ -387,7 +389,7 @@ class TVCCoverMixin(object):
         self.failUnlessEqual(song["coverartmime"][0], "image/jpeg")
 
     def test_handle_invalid_coverart(self):
-        crap = ".-a,a.f,afa-,.-"
+        crap = u".-a,a.f,afa-,.-"
         song = self.MutagenType(self.filename)
         song["coverart"] = crap
         song.save()
@@ -406,12 +408,12 @@ class TVCCoverMixin(object):
         pic = Picture()
         pic.data = _get_jpeg()
         pic.type = APICType.COVER_FRONT
-        b64pic_cover = base64.b64encode(pic.write())
+        b64pic_cover = base64.b64encode(pic.write()).decode("ascii")
 
         pic2 = Picture()
         pic2.data = _get_jpeg(size=6)
         pic2.type = APICType.COVER_BACK
-        b64pic_other = base64.b64encode(pic2.write())
+        b64pic_other = base64.b64encode(pic2.write()).decode("ascii")
 
         song = self.MutagenType(self.filename)
         song["metadata_block_picture"] = [b64pic_other, b64pic_cover]
@@ -451,9 +453,9 @@ class TVCCoverMixin(object):
         self.failUnlessEqual(song["metadata_block_picture"][0], crap)
 
     def test_handle_invalid_flac_picture(self):
-        crap = ".-a,a.f,afa-,.-"
+        crap = b".-a,a.f,afa-,.-"
         song = self.MutagenType(self.filename)
-        song["metadata_block_picture"] = base64.b64encode(crap)
+        song["metadata_block_picture"] = base64.b64encode(crap).decode("ascii")
         song.save()
         song = self.QLType(self.filename)
         self.failIf(song.get_primary_image())
@@ -462,7 +464,7 @@ class TVCCoverMixin(object):
     def test_set_image(self):
         data = _get_jpeg()
         song = self.MutagenType(self.filename)
-        song["coverart"] = base64.b64encode(data)
+        song["coverart"] = base64.b64encode(data).decode("ascii")
         song["coverartmime"] = "image/jpeg"
         song.save()
 
@@ -485,9 +487,7 @@ class TVCCoverMixin(object):
 class TVCCoverOgg(TVCCover, TVCCoverMixin):
     def setUp(self):
         TVCCover.setUp(self)
-        h, self.filename = mkstemp(".ogg")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.ogg'))
         self.MutagenType = OggVorbis
         self.QLType = OggFile
 
@@ -495,9 +495,7 @@ class TVCCoverOgg(TVCCover, TVCCoverMixin):
 class TVCCoverFlac(TVCCover, TVCCoverMixin):
     def setUp(self):
         TVCCover.setUp(self)
-        h, self.filename = mkstemp(".flac")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.flac'))
         self.MutagenType = FLAC
         self.QLType = FLACFile
 
@@ -505,15 +503,13 @@ class TVCCoverFlac(TVCCover, TVCCoverMixin):
 class TFlacPicture(TestCase):
     def setUp(self):
         config.init()
-        h, self.filename = mkstemp(".flac")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), self.filename)
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.flac'))
 
     def test_get_images(self):
         pic = Picture()
         pic.data = _get_jpeg()
         pic.type = APICType.COVER_FRONT
-        b64pic_cover = base64.b64encode(pic.write())
+        b64pic_cover = base64.b64encode(pic.write()).decode("ascii")
 
         # metadata_block_picture
         song = FLAC(self.filename)
@@ -537,7 +533,7 @@ class TFlacPicture(TestCase):
         self.assertEqual(song.get_images()[-1].type, APICType.COVER_BACK)
 
     def test_get_image(self):
-        data = "abc"
+        data = b"abc"
         song = FLAC(self.filename)
         pic = Picture()
         pic.data = data
@@ -550,7 +546,7 @@ class TFlacPicture(TestCase):
         self.failUnlessEqual(fn.read(), pic.data)
 
     def test_clear_images(self):
-        data = "abc"
+        data = b"abc"
         song = FLAC(self.filename)
         pic = Picture()
         pic.data = data
@@ -581,9 +577,8 @@ class TFlacPicture(TestCase):
 class TOggFile(TVCFile, TVCFileMixin):
     def setUp(self):
         TVCFile.setUp(self)
-        h, self.filename = mkstemp(".ogg")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.ogg'), self.filename)
+
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.ogg'))
         self.song = OggFile(self.filename)
 
     def tearDown(self):
@@ -600,9 +595,8 @@ class TOggFile(TVCFile, TVCFileMixin):
 class TOggOpusFile(TVCFile, TVCFileMixin):
     def setUp(self):
         TVCFile.setUp(self)
-        h, self.filename = mkstemp(".ogg")
-        os.close(h)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.opus'), self.filename)
+
+        self.filename = get_temp_copy(os.path.join(DATA_DIR, 'empty.opus'))
         self.song = OggOpusFile(self.filename)
 
     def test_length(self):
