@@ -8,13 +8,13 @@
 from gi.repository import Gtk
 
 from tests import TestCase
-from quodlibet import const
+import quodlibet
 
 
 class TIconTheme(TestCase):
     def test_icon_theme(self):
         theme = Gtk.IconTheme.get_default()
-        theme.append_search_path(const.IMAGEDIR)
+        theme.append_search_path(quodlibet.get_image_dir())
 
         for i in ["quodlibet", "exfalso", "quodlibet-missing-cover"]:
             self.failUnless(theme.has_icon(i))
