@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 from gi.repository import Gtk
 
 import os
-import shutil
+
+from quodlibet.formats import AudioFileError
 from quodlibet import config
 from quodlibet.util import connect_obj
 from quodlibet.formats import AudioFile
 
 from tests import TestCase, DATA_DIR, mkstemp
-from .helper import capture_output
+from .helper import capture_output, get_temp_copy
 
-from quodlibet.library.libraries import *
+from quodlibet.library.libraries import Library, PicklingMixin, SongLibrary, \
+    FileLibrary, AlbumLibrary, SongFileLibrary
 
 
 class Fake(int):
@@ -411,7 +417,7 @@ class TSongFileLibrary(TSongLibrary):
             new = self.Fake(100)
 
             def error():
-                raise IOError
+                raise AudioFileError
             new.reload = error
             new._valid = False
             changed, removed = self.library._load_item(new)
@@ -435,10 +441,7 @@ class TSongFileLibrary(TSongLibrary):
         self.failUnless(self.library.masked(new))
 
     def __get_file(self):
-        fd, filename = mkstemp(".flac")
-        os.close(fd)
-        shutil.copy(os.path.join(DATA_DIR, 'empty.flac'), filename)
-        return filename
+        return get_temp_copy(os.path.join(DATA_DIR, 'empty.flac'))
 
     def test_add_filename(self):
         config.init()
