@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
 
 import os
 import sys
@@ -20,7 +23,7 @@ except ImportError:
     pass
 
 from quodlibet.player import PlayerError
-from quodlibet.util import sanitize_tags
+from quodlibet.util import sanitize_tags, print_w
 from quodlibet.formats import MusicFile
 from quodlibet.compat import long
 from quodlibet import config
