@@ -1,23 +1,36 @@
 # -*- coding: utf-8 -*-
-import uuid
-from quodlibet.config import HardCodedRatingsPrefs
-from quodlibet.util.path import *
-from quodlibet.util import re_escape
-from quodlibet.util.string import decode, encode, split_escape, join_escape
-from quodlibet.util.string.splitters import *
-from quodlibet.util.library import *
-from tests import TestCase, skipIf
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
 
+import uuid
 import tempfile
 import os
 import sys
 import threading
 import traceback
 import time
-from quodlibet import util
-from quodlibet import config
+
 from quodlibet.compat import text_type, PY2
+from quodlibet.config import HardCodedRatingsPrefs
+from quodlibet import config
+from quodlibet import util
+from quodlibet.util.dprint import print_exc, format_exception, extract_tb
 from quodlibet.util import format_time_long as f_t_l
+from quodlibet.util import re_escape
+from quodlibet.util.library import set_scan_dirs, get_scan_dirs
+from quodlibet.util.path import is_fsnative, fsnative2glib, glib2fsnative, \
+    parse_xdg_user_dirs, xdg_get_system_data_dirs, escape_filename, \
+    strip_win32_incompat_from_path, xdg_get_cache_home, environ, \
+    xdg_get_data_home, unexpand, expanduser, xdg_get_user_dirs, \
+    xdg_get_config_home, fsnative, bytes2fsnative, fsnative2bytes, \
+    get_temp_cover_file, mkdir, getcwd, mtime
+from quodlibet.util.string import decode, encode, split_escape, join_escape
+from quodlibet.util.string.splitters import split_people, split_title, \
+    split_album
+
+from . import TestCase, skipIf
+from .helper import capture_output
 
 
 is_win = os.name == "nt"
@@ -743,7 +756,7 @@ class Tescape_filename(TestCase):
         self.assertTrue(is_fsnative(result))
 
 
-@skipIf(is_win)
+@skipIf(is_win, "not on Windows")
 class Tload_library(TestCase):
 
     def test_libc(self):
@@ -1091,3 +1104,61 @@ class Tgdecode(TestCase):
             self.assertTrue(isinstance(util.gdecode(b"foo"), text_type))
         else:
             self.assertTrue(isinstance(util.gdecode(u"foo"), text_type))
+
+
+class Tget_module_dir(TestCase):
+
+    def test_self(self):
+        path = util.get_module_dir()
+        self.assertTrue(is_fsnative(path))
+        self.assertTrue(os.path.exists(path))
+
+    def test_other(self):
+        path = util.get_module_dir(util)
+        self.assertTrue(is_fsnative(path))
+        self.assertTrue(os.path.exists(path))
+
+
+class Tget_ca_file(TestCase):
+
+    def test_main(self):
+        path = util.get_ca_file()
+        if path is not None:
+            self.assertTrue(is_fsnative(path))
+            self.assertTrue(os.path.exists(path))
+
+
+class Tprint_exc(TestCase):
+
+    def test_main(self):
+        try:
+            1 / 0
+        except:
+            with capture_output():
+                print_exc()
+
+
+class Tformat_exception(TestCase):
+
+    def test_main(self):
+        try:
+            1 / 0
+        except:
+            result = format_exception(*sys.exc_info())
+            self.assertTrue(isinstance(result, list))
+            self.assertTrue(all([isinstance(l, text_type) for l in result]))
+
+
+class Textract_tb(TestCase):
+
+    def test_main(self):
+        try:
+            1 / 0
+        except:
+            result = extract_tb(sys.exc_info()[2])
+            self.assertTrue(isinstance(result, list))
+            for fn, l, fu, text in result:
+                self.assertTrue(is_fsnative(fn))
+                self.assertTrue(isinstance(l, int))
+                self.assertTrue(isinstance(fu, text_type))
+                self.assertTrue(isinstance(text, text_type))
