@@ -1,11 +1,15 @@
 # -*- coding: utf-8 -*-
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 2 as
+# published by the Free Software Foundation
+
 import shutil
 import os
 from quodlibet import config
 
 from tests import TestCase, mkdtemp
 from quodlibet.formats import AudioFile as Fakesong
-from quodlibet.formats._audio import INTERN_NUM_DEFAULT, PEOPLE
+from quodlibet.formats._audio import NUMERIC_ZERO_DEFAULT, PEOPLE
 from quodlibet.util.collection import Album, Playlist, avg, bayesian_average, \
     FileBackedPlaylist
 from quodlibet.library.libraries import FileLibrary
@@ -232,7 +236,7 @@ class TAlbum(TestCase):
         for p in PEOPLE:
             failUnlessEq(album(p, "x"), song(p, "x"))
 
-        for p in INTERN_NUM_DEFAULT:
+        for p in NUMERIC_ZERO_DEFAULT:
             failUnlessEq(album(p, "x"), song(p, "x"))
 
     def test_methods(s):
